@@ -27,7 +27,7 @@ class DsClient(AbstractClient):
 
 
     def CheckVcode(self, request):
-        """检测验证码接口。此接口用于企业电子合同平台通过给用户发送短信验证码，以短信授权方式签署合同。此接口配合发送验证码接口使用。
+        r"""检测验证码接口。此接口用于企业电子合同平台通过给用户发送短信验证码，以短信授权方式签署合同。此接口配合发送验证码接口使用。
 
         用户在企业电子合同平台输入收到的验证码后，由企业电子合同平台调用该接口向腾讯云提交确认受托签署合同验证码命令。验证码验证正确时，本次合同签署的授权成功。
 
@@ -52,7 +52,7 @@ class DsClient(AbstractClient):
 
 
     def CreateContractByUpload(self, request):
-        """此接口适用于：客户平台通过上传PDF文件作为合同，以备未来进行签署。接口返回任务号，可调用DescribeTaskStatus接口查看任务执行结果。
+        r"""此接口适用于：客户平台通过上传PDF文件作为合同，以备未来进行签署。接口返回任务号，可调用DescribeTaskStatus接口查看任务执行结果。
 
         :param request: Request instance for CreateContractByUpload.
         :type request: :class:`tencentcloud.ds.v20180523.models.CreateContractByUploadRequest`
@@ -75,7 +75,7 @@ class DsClient(AbstractClient):
 
 
     def CreateEnterpriseAccount(self, request):
-        """为企业电子合同平台的最终企业用户进行开户。在企业电子合同平台进行操作的企业用户，企业电子合同平台向腾讯云发送企业用户的信息，提交开户命令。腾讯云接到请求后，自动为企业电子合同平台的企业用户生成一张数字证书。
+        r"""为企业电子合同平台的最终企业用户进行开户。在企业电子合同平台进行操作的企业用户，企业电子合同平台向腾讯云发送企业用户的信息，提交开户命令。腾讯云接到请求后，自动为企业电子合同平台的企业用户生成一张数字证书。
 
         :param request: Request instance for CreateEnterpriseAccount.
         :type request: :class:`tencentcloud.ds.v20180523.models.CreateEnterpriseAccountRequest`
@@ -98,7 +98,7 @@ class DsClient(AbstractClient):
 
 
     def CreatePersonalAccount(self, request):
-        """为企业电子合同平台的最终个人用户进行开户。在企业电子合同平台进行操作的个人用户，企业电子合同平台向腾讯云发送个人用户的信息，提交开户命令。腾讯云接到请求后，自动为企业电子合同平台的个人用户生成一张数字证书。
+        r"""为企业电子合同平台的最终个人用户进行开户。在企业电子合同平台进行操作的个人用户，企业电子合同平台向腾讯云发送个人用户的信息，提交开户命令。腾讯云接到请求后，自动为企业电子合同平台的个人用户生成一张数字证书。
 
         :param request: Request instance for CreatePersonalAccount.
         :type request: :class:`tencentcloud.ds.v20180523.models.CreatePersonalAccountRequest`
@@ -121,7 +121,7 @@ class DsClient(AbstractClient):
 
 
     def CreateSeal(self, request):
-        """此接口用于客户电子合同平台增加某用户的印章图片。客户平台可以调用此接口增加某用户的印章图片。
+        r"""此接口用于客户电子合同平台增加某用户的印章图片。客户平台可以调用此接口增加某用户的印章图片。
 
         :param request: Request instance for CreateSeal.
         :type request: :class:`tencentcloud.ds.v20180523.models.CreateSealRequest`
@@ -144,7 +144,7 @@ class DsClient(AbstractClient):
 
 
     def DeleteAccount(self, request):
-        """删除企业电子合同平台的最终用户。调用该接口后，腾讯云将删除该用户账号。删除账号后，已经签名的合同不受影响。
+        r"""删除企业电子合同平台的最终用户。调用该接口后，腾讯云将删除该用户账号。删除账号后，已经签名的合同不受影响。
 
         :param request: Request instance for DeleteAccount.
         :type request: :class:`tencentcloud.ds.v20180523.models.DeleteAccountRequest`
@@ -167,7 +167,7 @@ class DsClient(AbstractClient):
 
 
     def DeleteSeal(self, request):
-        """删除印章接口，删除指定账号的某个印章
+        r"""删除印章接口，删除指定账号的某个印章
 
         :param request: Request instance for DeleteSeal.
         :type request: :class:`tencentcloud.ds.v20180523.models.DeleteSealRequest`
@@ -190,7 +190,7 @@ class DsClient(AbstractClient):
 
 
     def DescribeTaskStatus(self, request):
-        """接口使用于：客户平台可使用该接口查询任务执行状态或者执行结果
+        r"""接口使用于：客户平台可使用该接口查询任务执行状态或者执行结果
 
         :param request: Request instance for DescribeTaskStatus.
         :type request: :class:`tencentcloud.ds.v20180523.models.DescribeTaskStatusRequest`
@@ -213,7 +213,7 @@ class DsClient(AbstractClient):
 
 
     def DownloadContract(self, request):
-        """下载合同接口。调用该接口可以下载签署中和签署完成的合同。接口返回任务号，可调用DescribeTaskStatus接口查看任务执行结果。
+        r"""下载合同接口。调用该接口可以下载签署中和签署完成的合同。接口返回任务号，可调用DescribeTaskStatus接口查看任务执行结果。
 
         :param request: Request instance for DownloadContract.
         :type request: :class:`tencentcloud.ds.v20180523.models.DownloadContractRequest`
@@ -236,7 +236,7 @@ class DsClient(AbstractClient):
 
 
     def SendVcode(self, request):
-        """发送验证码接口。此接口用于：企业电子合同平台需要腾讯云发送验证码对其用户进行验证时调用，腾讯云将向其用户联系手机(企业电子合同平台为用户开户时通过接口传入)发送验证码，以验证码授权方式签署合同。用户验证工作由企业电子合同平台自身完成。
+        r"""发送验证码接口。此接口用于：企业电子合同平台需要腾讯云发送验证码对其用户进行验证时调用，腾讯云将向其用户联系手机(企业电子合同平台为用户开户时通过接口传入)发送验证码，以验证码授权方式签署合同。用户验证工作由企业电子合同平台自身完成。
 
         :param request: Request instance for SendVcode.
         :type request: :class:`tencentcloud.ds.v20180523.models.SendVcodeRequest`
@@ -259,7 +259,7 @@ class DsClient(AbstractClient):
 
 
     def SignContractByCoordinate(self, request):
-        """此接口适用于：客户平台在创建好合同后，由合同签署方对创建的合同内容进行确认，无误后再进行签署。客户平台使用该接口提供详细的PDF文档签名坐标进行签署。
+        r"""此接口适用于：客户平台在创建好合同后，由合同签署方对创建的合同内容进行确认，无误后再进行签署。客户平台使用该接口提供详细的PDF文档签名坐标进行签署。
 
         :param request: Request instance for SignContractByCoordinate.
         :type request: :class:`tencentcloud.ds.v20180523.models.SignContractByCoordinateRequest`
@@ -282,7 +282,7 @@ class DsClient(AbstractClient):
 
 
     def SignContractByKeyword(self, request):
-        """此接口适用于：客户平台在创建好合同后，由合同签署方对创建的合同内容进行确认，无误后再进行签署。客户平台使用该接口对PDF合同文档按照关键字和坐标进行签署。
+        r"""此接口适用于：客户平台在创建好合同后，由合同签署方对创建的合同内容进行确认，无误后再进行签署。客户平台使用该接口对PDF合同文档按照关键字和坐标进行签署。
 
         :param request: Request instance for SignContractByKeyword.
         :type request: :class:`tencentcloud.ds.v20180523.models.SignContractByKeywordRequest`
