@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,7 +27,7 @@ class DtsClient(AbstractClient):
 
 
     def ActivateSubscribe(self, request):
-        """本接口用于配置数据订阅，只有在未配置状态的订阅实例才能调用此接口。
+        r"""本接口用于配置数据订阅，只有在未配置状态的订阅实例才能调用此接口。
 
         :param request: Request instance for ActivateSubscribe.
         :type request: :class:`tencentcloud.dts.v20180330.models.ActivateSubscribeRequest`
@@ -46,11 +46,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CompleteMigrateJob(self, request):
-        """本接口（CompleteMigrateJob）用于完成数据迁移任务。
+        r"""本接口（CompleteMigrateJob）用于完成数据迁移任务。
         选择采用增量迁移方式的任务, 需要在迁移进度进入准备完成阶段后, 调用本接口, 停止迁移增量数据。
         通过DescribeMigrateJobs接口查询到任务的状态为准备完成（status=8）时，此时可以调用本接口完成迁移任务。
 
@@ -71,11 +71,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateMigrateCheckJob(self, request):
-        """创建校验迁移任务
+        r"""创建校验迁移任务
         在开始迁移前, 必须调用本接口创建校验, 且校验成功后才能开始迁移. 校验的结果可以通过DescribeMigrateCheckJob查看.
         校验成功后,迁移任务若有修改, 则必须重新创建校验并通过后, 才能开始迁移.
 
@@ -98,11 +98,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateMigrateJob(self, request):
-        """本接口（CreateMigrateJob）用于创建数据迁移任务。
+        r"""本接口（CreateMigrateJob）用于创建数据迁移任务。
 
         如果是金融区链路, 请使用域名: dts.ap-shenzhen-fsi.tencentcloudapi.com
 
@@ -123,11 +123,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateSubscribe(self, request):
-        """本接口(CreateSubscribe)用于创建一个数据订阅实例。
+        r"""本接口(CreateSubscribe)用于创建一个数据订阅实例。
 
         :param request: Request instance for CreateSubscribe.
         :type request: :class:`tencentcloud.dts.v20180330.models.CreateSubscribeRequest`
@@ -146,11 +146,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteMigrateJob(self, request):
-        """本接口（DeleteMigrationJob）用于删除数据迁移任务。当通过DescribeMigrateJobs接口查询到任务的状态为：检验中（status=3）、运行中（status=7）、准备完成（status=8）、撤销中（status=11）或者完成中（status=12）时，不允许删除任务。
+        r"""本接口（DeleteMigrationJob）用于删除数据迁移任务。当通过DescribeMigrateJobs接口查询到任务的状态为：检验中（status=3）、运行中（status=7）、准备完成（status=8）、撤销中（status=11）或者完成中（status=12）时，不允许删除任务。
 
         :param request: Request instance for DeleteMigrateJob.
         :type request: :class:`tencentcloud.dts.v20180330.models.DeleteMigrateJobRequest`
@@ -169,11 +169,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAsyncRequestInfo(self, request):
-        """本接口（DescribeAsyncRequestInfo）用于查询任务执行结果
+        r"""本接口（DescribeAsyncRequestInfo）用于查询任务执行结果
 
         :param request: Request instance for DescribeAsyncRequestInfo.
         :type request: :class:`tencentcloud.dts.v20180330.models.DescribeAsyncRequestInfoRequest`
@@ -192,11 +192,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMigrateCheckJob(self, request):
-        """本接口用于创建校验后,获取校验的结果. 能查询到当前校验的状态和进度.
+        r"""本接口用于创建校验后,获取校验的结果. 能查询到当前校验的状态和进度.
         若通过校验, 则可调用'StartMigrateJob' 开始迁移.
         若未通过校验, 则能查询到校验失败的原因. 请按照报错, 通过'ModifyMigrateJob'修改迁移配置或是调整源/目标实例的相关参数.
 
@@ -217,11 +217,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMigrateJobs(self, request):
-        """查询数据迁移任务.
+        r"""查询数据迁移任务.
         如果是金融区链路, 请使用域名: https://dts.ap-shenzhen-fsi.tencentcloudapi.com
 
         :param request: Request instance for DescribeMigrateJobs.
@@ -241,34 +241,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeRegionConf(self, request):
-        """本接口（DescribeRegionConf）用于查询可售卖订阅实例的地域
-
-        :param request: Request instance for DescribeRegionConf.
-        :type request: :class:`tencentcloud.dts.v20180330.models.DescribeRegionConfRequest`
-        :rtype: :class:`tencentcloud.dts.v20180330.models.DescribeRegionConfResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeRegionConf", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeRegionConfResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSubscribeConf(self, request):
-        """本接口（DescribeSubscribeConf）用于查询订阅实例配置
+        r"""本接口（DescribeSubscribeConf）用于查询订阅实例配置
 
         :param request: Request instance for DescribeSubscribeConf.
         :type request: :class:`tencentcloud.dts.v20180330.models.DescribeSubscribeConfRequest`
@@ -287,11 +264,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSubscribes(self, request):
-        """本接口(DescribeSubscribes)获取数据订阅实例信息列表，默认分页，每次返回20条
+        r"""本接口(DescribeSubscribes)获取数据订阅实例信息列表，默认分页，每次返回20条
 
         :param request: Request instance for DescribeSubscribes.
         :type request: :class:`tencentcloud.dts.v20180330.models.DescribeSubscribesRequest`
@@ -310,11 +287,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def IsolateSubscribe(self, request):
-        """本接口（IsolateSubscribe）用于隔离小时计费的订阅实例。调用后，订阅实例将不能使用，同时停止计费。
+        r"""本接口（IsolateSubscribe）用于隔离小时计费的订阅实例。调用后，订阅实例将不能使用，同时停止计费。
 
         :param request: Request instance for IsolateSubscribe.
         :type request: :class:`tencentcloud.dts.v20180330.models.IsolateSubscribeRequest`
@@ -333,11 +310,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyMigrateJob(self, request):
-        """本接口（ModifyMigrateJob）用于修改数据迁移任务。
+        r"""本接口（ModifyMigrateJob）用于修改数据迁移任务。
         当迁移任务处于下述状态时，允许调用本接口修改迁移任务：迁移创建中（status=1）、 校验成功(status=4)、校验失败(status=5)、迁移失败(status=10)。但源实例、目标实例类型和目标实例地域不允许修改。
 
         如果是金融区链路, 请使用域名: dts.ap-shenzhen-fsi.tencentcloudapi.com
@@ -359,11 +336,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifySubscribeAutoRenewFlag(self, request):
-        """修改订阅实例自动续费标识
+        r"""修改订阅实例自动续费标识
 
         :param request: Request instance for ModifySubscribeAutoRenewFlag.
         :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeAutoRenewFlagRequest`
@@ -382,11 +359,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifySubscribeConsumeTime(self, request):
-        """本接口(ModifySubscribeConsumeTime)用于修改数据订阅通道的消费时间点
+        r"""本接口(ModifySubscribeConsumeTime)用于修改数据订阅通道的消费时间点
 
         :param request: Request instance for ModifySubscribeConsumeTime.
         :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeConsumeTimeRequest`
@@ -405,11 +382,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifySubscribeName(self, request):
-        """本接口(ModifySubscribeName)用于修改数据订阅实例的名称
+        r"""本接口(ModifySubscribeName)用于修改数据订阅实例的名称
 
         :param request: Request instance for ModifySubscribeName.
         :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeNameRequest`
@@ -428,11 +405,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifySubscribeObjects(self, request):
-        """本接口(ModifySubscribeObjects)用于修改数据订阅通道的订阅规则
+        r"""本接口(ModifySubscribeObjects)用于修改数据订阅通道的订阅规则
 
         :param request: Request instance for ModifySubscribeObjects.
         :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeObjectsRequest`
@@ -451,11 +428,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifySubscribeVipVport(self, request):
-        """本接口(ModifySubscribeVipVport)用于修改数据订阅实例的IP和端口号
+        r"""本接口(ModifySubscribeVipVport)用于修改数据订阅实例的IP和端口号
 
         :param request: Request instance for ModifySubscribeVipVport.
         :type request: :class:`tencentcloud.dts.v20180330.models.ModifySubscribeVipVportRequest`
@@ -474,11 +451,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def OfflineIsolatedSubscribe(self, request):
-        """本接口（OfflineIsolatedSubscribe）用于下线已隔离的数据订阅实例
+        r"""本接口（OfflineIsolatedSubscribe）用于下线已隔离的数据订阅实例
 
         :param request: Request instance for OfflineIsolatedSubscribe.
         :type request: :class:`tencentcloud.dts.v20180330.models.OfflineIsolatedSubscribeRequest`
@@ -497,11 +474,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ResetSubscribe(self, request):
-        """本接口(ResetSubscribe)用于重置数据订阅实例，已经激活的数据订阅实例，重置后可以使用ActivateSubscribe接口绑定其他的数据库实例
+        r"""本接口(ResetSubscribe)用于重置数据订阅实例，已经激活的数据订阅实例，重置后可以使用ActivateSubscribe接口绑定其他的数据库实例
 
         :param request: Request instance for ResetSubscribe.
         :type request: :class:`tencentcloud.dts.v20180330.models.ResetSubscribeRequest`
@@ -520,11 +497,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StartMigrateJob(self, request):
-        """本接口（StartMigrationJob）用于启动迁移任务。非定时迁移任务会在调用后立即开始迁移，定时任务则会开始倒计时。
+        r"""本接口（StartMigrationJob）用于启动迁移任务。非定时迁移任务会在调用后立即开始迁移，定时任务则会开始倒计时。
         调用此接口前，请务必先使用CreateMigrateCheckJob校验数据迁移任务，并通过DescribeMigrateJobs接口查询到任务状态为校验通过（status=4）时，才能启动数据迁移任务。
 
         :param request: Request instance for StartMigrateJob.
@@ -544,11 +521,11 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StopMigrateJob(self, request):
-        """本接口（StopMigrateJob）用于撤销数据迁移任务。
+        r"""本接口（StopMigrateJob）用于撤销数据迁移任务。
         在迁移过程中允许调用该接口撤销迁移, 撤销迁移的任务会失败。通过DescribeMigrateJobs接口查询到任务状态为运行中（status=7）或准备完成（status=8）时，才能撤销数据迁移任务。
 
         :param request: Request instance for StopMigrateJob.
@@ -568,4 +545,4 @@ class DtsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
