@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,7 +27,7 @@ class FaceidClient(AbstractClient):
 
 
     def BankCard2EVerification(self, request):
-        """本接口用于校验姓名和银行卡号的真实性和一致性。
+        r"""本接口用于校验姓名和银行卡号的真实性和一致性。
 
         :param request: Request instance for BankCard2EVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.BankCard2EVerificationRequest`
@@ -50,7 +50,7 @@ class FaceidClient(AbstractClient):
 
 
     def BankCard4EVerification(self, request):
-        """本接口用于输入银行卡号、姓名、开户证件号、开户手机号，校验信息的真实性和一致性。
+        r"""本接口用于输入银行卡号、姓名、开户证件号、开户手机号，校验信息的真实性和一致性。
 
         :param request: Request instance for BankCard4EVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.BankCard4EVerificationRequest`
@@ -73,7 +73,7 @@ class FaceidClient(AbstractClient):
 
 
     def BankCardVerification(self, request):
-        """本接口用于银行卡号、姓名、开户证件号信息的真实性和一致性。
+        r"""本接口用于银行卡号、姓名、开户证件号信息的真实性和一致性。
 
         :param request: Request instance for BankCardVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.BankCardVerificationRequest`
@@ -96,7 +96,7 @@ class FaceidClient(AbstractClient):
 
 
     def CheckBankCardInformation(self, request):
-        """银行卡基础信息查询
+        r"""银行卡基础信息查询
 
         :param request: Request instance for CheckBankCardInformation.
         :type request: :class:`tencentcloud.faceid.v20180301.models.CheckBankCardInformationRequest`
@@ -119,7 +119,7 @@ class FaceidClient(AbstractClient):
 
 
     def CheckEidTokenStatus(self, request):
-        """用于轮询E证通H5场景EidToken验证状态。
+        r"""用于轮询E证通H5场景EidToken验证状态。
 
         :param request: Request instance for CheckEidTokenStatus.
         :type request: :class:`tencentcloud.faceid.v20180301.models.CheckEidTokenStatusRequest`
@@ -142,7 +142,7 @@ class FaceidClient(AbstractClient):
 
 
     def CheckIdCardInformation(self, request):
-        """传入身份证人像面照片，识别身份证照片上的信息，并将姓名、身份证号、身份证人像照片与权威库的证件照进行比对，是否属于同一个人，从而验证身份证信息的真实性。
+        r"""传入身份证人像面照片，识别身份证照片上的信息，并将姓名、身份证号、身份证人像照片与权威库的证件照进行比对，是否属于同一个人，从而验证身份证信息的真实性。
 
         :param request: Request instance for CheckIdCardInformation.
         :type request: :class:`tencentcloud.faceid.v20180301.models.CheckIdCardInformationRequest`
@@ -165,7 +165,7 @@ class FaceidClient(AbstractClient):
 
 
     def CheckIdNameDate(self, request):
-        """本接口用于校验姓名、身份证号、身份证有效期的真实性和一致性。
+        r"""本接口用于校验姓名、身份证号、身份证有效期的真实性和一致性。
 
         :param request: Request instance for CheckIdNameDate.
         :type request: :class:`tencentcloud.faceid.v20180301.models.CheckIdNameDateRequest`
@@ -188,7 +188,7 @@ class FaceidClient(AbstractClient):
 
 
     def CheckPhoneAndName(self, request):
-        """手机号二要素核验接口用于校验手机号和姓名的真实性和一致性，支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
+        r"""手机号二要素核验接口用于校验手机号和姓名的真实性和一致性，支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
 
         :param request: Request instance for CheckPhoneAndName.
         :type request: :class:`tencentcloud.faceid.v20180301.models.CheckPhoneAndNameRequest`
@@ -211,7 +211,7 @@ class FaceidClient(AbstractClient):
 
 
     def DetectAIFakeFaces(self, request):
-        """基于多模态的AI大模型算法，提供对人脸图片、视频的防攻击检测能力，可针对性有效识别高仿真的AIGC换脸、高清翻拍、批量黑产攻击、水印等攻击痕迹，增强对图片和视频的防伪安全能力。
+        r"""基于多模态的AI大模型算法，提供对人脸图片、视频的防攻击检测能力，可针对性有效识别高仿真的AIGC换脸、高清翻拍、批量黑产攻击、水印等攻击痕迹，增强对图片和视频的防伪安全能力。
 
         :param request: Request instance for DetectAIFakeFaces.
         :type request: :class:`tencentcloud.faceid.v20180301.models.DetectAIFakeFacesRequest`
@@ -234,7 +234,7 @@ class FaceidClient(AbstractClient):
 
 
     def DetectAuth(self, request):
-        """每次调用人脸核身SaaS化服务前，需先调用本接口获取BizToken，用来串联核身流程，在验证完成后，用于获取验证结果信息。
+        r"""每次调用人脸核身SaaS化服务前，需先调用本接口获取BizToken，用来串联核身流程，在验证完成后，用于获取验证结果信息。
 
         :param request: Request instance for DetectAuth.
         :type request: :class:`tencentcloud.faceid.v20180301.models.DetectAuthRequest`
@@ -257,7 +257,7 @@ class FaceidClient(AbstractClient):
 
 
     def EncryptedPhoneVerification(self, request):
-        """本接口用于校验手机号、姓名和身份证号的真实性和一致性，入参支持明文、MD5和SHA256加密传输。
+        r"""本接口用于校验手机号、姓名和身份证号的真实性和一致性，入参支持明文、MD5和SHA256加密传输。
 
         :param request: Request instance for EncryptedPhoneVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.EncryptedPhoneVerificationRequest`
@@ -280,7 +280,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetActionSequence(self, request):
-        """使用动作活体检测模式前，需调用本接口获取动作顺序。
+        r"""使用动作活体检测模式前，需调用本接口获取动作顺序。
 
         :param request: Request instance for GetActionSequence.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetActionSequenceRequest`
@@ -303,7 +303,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetDetectInfo(self, request):
-        """完成验证后，用BizToken调用本接口获取结果信息，BizToken生成后三天内（3\*24\*3,600秒）可多次拉取。
+        r"""完成验证后，用BizToken调用本接口获取结果信息，BizToken生成后三天内（3\*24\*3,600秒）可多次拉取。
 
         :param request: Request instance for GetDetectInfo.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetDetectInfoRequest`
@@ -326,7 +326,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetDetectInfoEnhanced(self, request):
-        """完成验证后，用BizToken调用本接口获取结果信息，BizToken生成后三天内（3\*24\*3,600秒）可多次拉取。
+        r"""完成验证后，用BizToken调用本接口获取结果信息，BizToken生成后三天内（3\*24\*3,600秒）可多次拉取。
 
         :param request: Request instance for GetDetectInfoEnhanced.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetDetectInfoEnhancedRequest`
@@ -349,7 +349,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetEidResult(self, request):
-        """完成验证后，用EidToken调用本接口获取结果信息，EidToken生成后三天内（3\*24\*3,600秒）可多次拉取。
+        r"""完成验证后，用EidToken调用本接口获取结果信息，EidToken生成后三天内（3\*24\*3,600秒）可多次拉取。
 
         :param request: Request instance for GetEidResult.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetEidResultRequest`
@@ -372,7 +372,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetEidToken(self, request):
-        """每次调用E证通服务前，需先调用本接口获取EidToken，用来串联E证通流程，在验证完成后，用于获取E证通结果信息。
+        r"""每次调用E证通服务前，需先调用本接口获取EidToken，用来串联E证通流程，在验证完成后，用于获取E证通结果信息。
 
         :param request: Request instance for GetEidToken.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetEidTokenRequest`
@@ -395,7 +395,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetFaceIdResult(self, request):
-        """完成验证后，用FaceIdToken调用本接口获取结果信息，FaceIdToken生成后三天内（3\*24\*3,600秒）可多次拉取。
+        r"""完成验证后，用FaceIdToken调用本接口获取结果信息，FaceIdToken生成后三天内（3\*24\*3,600秒）可多次拉取。
 
         :param request: Request instance for GetFaceIdResult.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetFaceIdResultRequest`
@@ -418,7 +418,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetFaceIdRiskInfo(self, request):
-        """完成验证后，用FaceIdToken调用本接口获取设备风险相关信息，FaceIdToken生成后三天内（3\*24\*3,600秒）可多次拉取。
+        r"""完成验证后，用FaceIdToken调用本接口获取设备风险相关信息，FaceIdToken生成后三天内（3\*24\*3,600秒）可多次拉取。
 
         :param request: Request instance for GetFaceIdRiskInfo.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetFaceIdRiskInfoRequest`
@@ -441,7 +441,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetFaceIdToken(self, request):
-        """每次调用人脸核身SDK服务前，需先调用本接口获取SDKToken，用来串联核身流程，在验证完成后，用于获取验证结果信息，该token仅能核身一次。
+        r"""每次调用人脸核身SDK服务前，需先调用本接口获取SDKToken，用来串联核身流程，在验证完成后，用于获取验证结果信息，该token仅能核身一次。
 
         :param request: Request instance for GetFaceIdToken.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetFaceIdTokenRequest`
@@ -464,7 +464,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetFaceidRiskInfoToken(self, request):
-        """每次调用人脸核身SDK服务前，需先调用本接口获取SDKToken，用来串联核身流程，在验证完成后，用于获取风险结果信息，该Token仅能核身一次。
+        r"""每次调用人脸核身SDK服务前，需先调用本接口获取SDKToken，用来串联核身流程，在验证完成后，用于获取风险结果信息，该Token仅能核身一次。
 
         :param request: Request instance for GetFaceidRiskInfoToken.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetFaceidRiskInfoTokenRequest`
@@ -487,7 +487,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetLiveCode(self, request):
-        """使用数字活体检测模式前，需调用本接口获取数字验证码。
+        r"""使用数字活体检测模式前，需调用本接口获取数字验证码。
 
         :param request: Request instance for GetLiveCode.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetLiveCodeRequest`
@@ -510,7 +510,7 @@ class FaceidClient(AbstractClient):
 
 
     def GetWeChatBillDetails(self, request):
-        """查询微信渠道服务（微信小程序、微信原生H5、微信普通H5）的账单明细及计费状态。
+        r"""查询微信渠道服务（微信小程序、微信原生H5、微信普通H5）的账单明细及计费状态。
 
         :param request: Request instance for GetWeChatBillDetails.
         :type request: :class:`tencentcloud.faceid.v20180301.models.GetWeChatBillDetailsRequest`
@@ -533,7 +533,7 @@ class FaceidClient(AbstractClient):
 
 
     def IdCardOCRVerification(self, request):
-        """本接口用于校验姓名和身份证号的真实性和一致性，您可以通过输入姓名和身份证号或传入身份证人像面照片提供所需验证信息。
+        r"""本接口用于校验姓名和身份证号的真实性和一致性，您可以通过输入姓名和身份证号或传入身份证人像面照片提供所需验证信息。
 
         :param request: Request instance for IdCardOCRVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.IdCardOCRVerificationRequest`
@@ -556,7 +556,7 @@ class FaceidClient(AbstractClient):
 
 
     def IdCardVerification(self, request):
-        """传入姓名和身份证号，校验两者的真实性和一致性。
+        r"""传入姓名和身份证号，校验两者的真实性和一致性。
 
         :param request: Request instance for IdCardVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.IdCardVerificationRequest`
@@ -579,7 +579,7 @@ class FaceidClient(AbstractClient):
 
 
     def ImageRecognition(self, request):
-        """传入照片和身份信息，判断该照片与权威库的证件照是否属于同一个人（该接口已停止接入，新客户请使用<a href="https://cloud.tencent.com/document/product/1007/102203">照片人脸核身（V2.0）</a>接口）。
+        r"""传入照片和身份信息，判断该照片与权威库的证件照是否属于同一个人（该接口已停止接入，新客户请使用<a href="https://cloud.tencent.com/document/product/1007/102203">照片人脸核身（V2.0）</a>接口）。
 
         :param request: Request instance for ImageRecognition.
         :type request: :class:`tencentcloud.faceid.v20180301.models.ImageRecognitionRequest`
@@ -602,7 +602,7 @@ class FaceidClient(AbstractClient):
 
 
     def ImageRecognitionV2(self, request):
-        """传入照片和身份信息，判断该照片与权威库的证件照是否属于同一个人。
+        r"""传入照片和身份信息，判断该照片与权威库的证件照是否属于同一个人。
 
         :param request: Request instance for ImageRecognitionV2.
         :type request: :class:`tencentcloud.faceid.v20180301.models.ImageRecognitionV2Request`
@@ -625,7 +625,7 @@ class FaceidClient(AbstractClient):
 
 
     def Liveness(self, request):
-        """活体检测
+        r"""活体检测
 
         :param request: Request instance for Liveness.
         :type request: :class:`tencentcloud.faceid.v20180301.models.LivenessRequest`
@@ -648,7 +648,7 @@ class FaceidClient(AbstractClient):
 
 
     def LivenessCompare(self, request):
-        """传入视频和照片，先判断视频中是否为真人，判断为真人后，再判断该视频中的人与上传照片是否属于同一个人。
+        r"""传入视频和照片，先判断视频中是否为真人，判断为真人后，再判断该视频中的人与上传照片是否属于同一个人。
 
         :param request: Request instance for LivenessCompare.
         :type request: :class:`tencentcloud.faceid.v20180301.models.LivenessCompareRequest`
@@ -671,7 +671,7 @@ class FaceidClient(AbstractClient):
 
 
     def LivenessRecognition(self, request):
-        """传入视频和身份信息，先判断视频中是否为真人，判断为真人后，再判断该视频中的人与权威库的证件照是否属于同一个人。
+        r"""传入视频和身份信息，先判断视频中是否为真人，判断为真人后，再判断该视频中的人与权威库的证件照是否属于同一个人。
 
         :param request: Request instance for LivenessRecognition.
         :type request: :class:`tencentcloud.faceid.v20180301.models.LivenessRecognitionRequest`
@@ -694,7 +694,7 @@ class FaceidClient(AbstractClient):
 
 
     def MinorsVerification(self, request):
-        """通过传入手机号或姓名和身份证号，结合权威数据源和腾讯健康守护可信模型，判断该信息是否真实且年满18周岁。腾讯健康守护可信模型覆盖了上十亿手机库源，覆盖率高、准确率高，如果不在库中的手机号，还可以通过姓名+身份证进行兜底验证。
+        r"""通过传入手机号或姓名和身份证号，结合权威数据源和腾讯健康守护可信模型，判断该信息是否真实且年满18周岁。腾讯健康守护可信模型覆盖了上十亿手机库源，覆盖率高、准确率高，如果不在库中的手机号，还可以通过姓名+身份证进行兜底验证。
 
         :param request: Request instance for MinorsVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.MinorsVerificationRequest`
@@ -717,7 +717,7 @@ class FaceidClient(AbstractClient):
 
 
     def MobileNetworkTimeVerification(self, request):
-        """本接口用于查询手机号在网时长，输入手机号进行查询。
+        r"""本接口用于查询手机号在网时长，输入手机号进行查询。
 
         :param request: Request instance for MobileNetworkTimeVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.MobileNetworkTimeVerificationRequest`
@@ -740,7 +740,7 @@ class FaceidClient(AbstractClient):
 
 
     def MobileStatus(self, request):
-        """本接口用于验证手机号的状态，您可以输入手机号进行查询。
+        r"""本接口用于验证手机号的状态，您可以输入手机号进行查询。
 
         :param request: Request instance for MobileStatus.
         :type request: :class:`tencentcloud.faceid.v20180301.models.MobileStatusRequest`
@@ -763,7 +763,7 @@ class FaceidClient(AbstractClient):
 
 
     def ParseNfcData(self, request):
-        """解析SDK获取到的证件NFC数据，接口传入SDK返回的ReqId，返回证件信息（个别字段为特定证件类型特有）。SDK生成的ReqId五分钟内有效，重复查询仅收一次费。支持身份证类证件（二代身份证、港澳居住证、台湾居住证、外国人永居证）以及旅行类证件（港澳通行证、台湾通行证、台胞证、回乡证）的NFC识别及核验。
+        r"""解析SDK获取到的证件NFC数据，接口传入SDK返回的ReqId，返回证件信息（个别字段为特定证件类型特有）。SDK生成的ReqId五分钟内有效，重复查询仅收一次费。支持身份证类证件（二代身份证、港澳居住证、台湾居住证、外国人永居证）以及旅行类证件（港澳通行证、台湾通行证、台胞证、回乡证）的NFC识别及核验。
 
         :param request: Request instance for ParseNfcData.
         :type request: :class:`tencentcloud.faceid.v20180301.models.ParseNfcDataRequest`
@@ -786,7 +786,7 @@ class FaceidClient(AbstractClient):
 
 
     def PhoneVerification(self, request):
-        """本接口用于校验手机号、姓名和身份证号的真实性和一致性。支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
+        r"""本接口用于校验手机号、姓名和身份证号的真实性和一致性。支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
 
         :param request: Request instance for PhoneVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationRequest`
@@ -809,7 +809,7 @@ class FaceidClient(AbstractClient):
 
 
     def PhoneVerificationCMCC(self, request):
-        """本接口用于校验中国移动手机号、姓名和身份证号的真实性和一致性。中国移动支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
+        r"""本接口用于校验中国移动手机号、姓名和身份证号的真实性和一致性。中国移动支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
 
         :param request: Request instance for PhoneVerificationCMCC.
         :type request: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationCMCCRequest`
@@ -832,7 +832,7 @@ class FaceidClient(AbstractClient):
 
 
     def PhoneVerificationCTCC(self, request):
-        """本接口用于校验中国电信手机号、姓名和身份证号的真实性和一致性。中国电信支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
+        r"""本接口用于校验中国电信手机号、姓名和身份证号的真实性和一致性。中国电信支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
 
         :param request: Request instance for PhoneVerificationCTCC.
         :type request: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationCTCCRequest`
@@ -855,7 +855,7 @@ class FaceidClient(AbstractClient):
 
 
     def PhoneVerificationCUCC(self, request):
-        """本接口用于校验中国联通手机号、姓名和身份证号的真实性和一致性。中国联通支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
+        r"""本接口用于校验中国联通手机号、姓名和身份证号的真实性和一致性。中国联通支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
 
         :param request: Request instance for PhoneVerificationCUCC.
         :type request: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationCUCCRequest`
