@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,12 +23,42 @@ DRYRUNOPERATION = 'DryRunOperation'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# FailedOperation.CosOperationFailed
+FAILEDOPERATION_COSOPERATIONFAILED = 'FailedOperation.CosOperationFailed'
+
+# FailedOperation.DbOperationFailed
+FAILEDOPERATION_DBOPERATIONFAILED = 'FailedOperation.DbOperationFailed'
+
+# FailedOperation.GenVoicePrintIdFailed
+FAILEDOPERATION_GENVOICEPRINTIDFAILED = 'FailedOperation.GenVoicePrintIdFailed'
+
 # 登录态过期。
 FAILEDOPERATION_LOGINFAILED = 'FailedOperation.LoginFailed'
 
+# FailedOperation.NotAbility
+FAILEDOPERATION_NOTABILITY = 'FailedOperation.NotAbility'
+
+# FailedOperation.NotAllowed
+FAILEDOPERATION_NOTALLOWED = 'FailedOperation.NotAllowed'
+
+# FailedOperation.TaskExist
+FAILEDOPERATION_TASKEXIST = 'FailedOperation.TaskExist'
+
+# FailedOperation.TaskNotExist
+FAILEDOPERATION_TASKNOTEXIST = 'FailedOperation.TaskNotExist'
+
+# FailedOperation.UpdateVoicePrintIdNotFound
+FAILEDOPERATION_UPDATEVOICEPRINTIDNOTFOUND = 'FailedOperation.UpdateVoicePrintIdNotFound'
+
 # 欠费不可操作。
 FAILEDOPERATION_USERFEENEGATIVE = 'FailedOperation.UserFeeNegative'
 
+# FailedOperation.VoicePrintAudioCheckFailed
+FAILEDOPERATION_VOICEPRINTAUDIOCHECKFAILED = 'FailedOperation.VoicePrintAudioCheckFailed'
+
+# FailedOperation.VoicePrintRegistrationLimit
+FAILEDOPERATION_VOICEPRINTREGISTRATIONLIMIT = 'FailedOperation.VoicePrintRegistrationLimit'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -44,21 +74,39 @@ INVALIDPARAMETER_DATEINVALID = 'InvalidParameter.DateInvalid'
 # 输入日期超出60天查询范围。
 INVALIDPARAMETER_DATEOUTOFSIXTYDAYS = 'InvalidParameter.DateOutOfSixtyDays'
 
+# InvalidParameter.InvalidAudioInput
+INVALIDPARAMETER_INVALIDAUDIOINPUT = 'InvalidParameter.InvalidAudioInput'
+
+# InvalidParameter.InvalidVoicePrintIdList
+INVALIDPARAMETER_INVALIDVOICEPRINTIDLIST = 'InvalidParameter.InvalidVoicePrintIdList'
+
 # 标签不正确
 INVALIDPARAMETER_TAGKEY = 'InvalidParameter.TagKey'
 
+# InvalidParameter.TaskId
+INVALIDPARAMETER_TASKID = 'InvalidParameter.TaskId'
+
 # 查询时间范围错误。
 INVALIDPARAMETER_TIMERANGEERROR = 'InvalidParameter.TimeRangeError'
 
+# InvalidParameter.UserSig
+INVALIDPARAMETER_USERSIG = 'InvalidParameter.UserSig'
+
 # BizId 参数错误
 INVALIDPARAMETERVALUE_INVALIDBIZID = 'InvalidParameterValue.InvalidBizId'
 
+# 输入删除类型应为1或2。
+INVALIDPARAMETERVALUE_INVALIDDELETETYPE = 'InvalidParameterValue.InvalidDeleteType'
+
 # RecordMode参数错误
 INVALIDPARAMETERVALUE_INVALIDRECORDMODE = 'InvalidParameterValue.InvalidRecordMode'
 
 # RoomId 参数错误
 INVALIDPARAMETERVALUE_INVALIDROOMID = 'InvalidParameterValue.InvalidRoomId'
 
+# 不需要填写StrUid，请填写Uid
+INVALIDPARAMETERVALUE_INVALIDSTRUIN = 'InvalidParameterValue.InvalidStrUin'
+
 # 黑白名单格式错误
 INVALIDPARAMETERVALUE_INVALIDSUBSCRIBERECORDUSERIDS = 'InvalidParameterValue.InvalidSubscribeRecordUserIds'
 
@@ -71,6 +119,9 @@ INVALIDPARAMETERVALUE_INVALIDTASKID = 'InvalidParameterValue.InvalidTaskId'
 # 黑名单个数超过20个
 INVALIDPARAMETERVALUE_INVALIDUNSUBSCRIBEUSERIDS = 'InvalidParameterValue.InvalidUNSubscribeUserIds'
 
+# 不能同时输入uid和strUid
+INVALIDPARAMETERVALUE_INVALIDUINORSTRUIN = 'InvalidParameterValue.InvalidUinOrStrUin'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -80,6 +131,9 @@ LIMITEXCEEDED_APPLICATION = 'LimitExceeded.Application'
 # 缺少参数。
 MISSINGPARAMETER = 'MissingParameter'
 
+# MissingParameter.MissingVoicePrintUpdateParams
+MISSINGPARAMETER_MISSINGVOICEPRINTUPDATEPARAMS = 'MissingParameter.MissingVoicePrintUpdateParams'
+
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
@@ -89,6 +143,9 @@ RESOURCEINUSE_TASKINUSE = 'ResourceInUse.TaskInUse'
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
+# ResourceInsufficient.RequestRejection
+RESOURCEINSUFFICIENT_REQUESTREJECTION = 'ResourceInsufficient.RequestRejection'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
@@ -122,6 +179,9 @@ UNKNOWNPARAMETER = 'UnknownParameter'
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
+# 超过最大踢人数量
+UNSUPPORTEDOPERATION_LIMITDELETEEXCEEDED = 'UnsupportedOperation.LimitDeleteExceeded'
+
 # 语音转文本开关未开启。
 UNSUPPORTEDOPERATION_PTTSWITCHOFF = 'UnsupportedOperation.PTTSwitchOff'
 
