@@ -48,12 +48,10 @@ class LkeapClient(AbstractClient):
             -  支持96K上下文长度，最大输入长度64k，最大输出16k（默认4k），最大思维链输出长度32k。
         - DeepSeek-R1-0528（model 参数值为**deepseek-r1-0528**）
             - DeepSeek-R1-0528为671B 模型，架构优化与训练策略升级后，相比上一版本在代码生成、长文本处理和复杂推理领域提升明显。
-            -  支持96K上下文长度，最大输入长度64k，最大输出16k（默认4k），最大思维链输出长度32k。
+            -  支持128K上下文长度，最大输入长度96k，最大输出16k（默认4k），最大思维链输出长度32k。
         - DeepSeek-V3.1（model 参数值为 deepseek-v3.1）
-
-            - DeepSeek-V3.1 为685B 参数 MoE 模型，支持混合推理架构，有更高的思考效率和更强的 Agent 能力。目前尚处于限制性开放的试运行阶段，如需申请开通请联系售前客服或商务经理。
-
-
+            - DeepSeek-V3.1 为685B 参数 MoE 模型，支持混合推理架构，有更高的思考效率和更强的 Agent 能力。
+            -  支持128K上下文长度，最大输入长度96k，最大输出32k（默认4k），最大思维链输出长度32k。
 
 
         ### 计费说明
@@ -68,6 +66,8 @@ class LkeapClient(AbstractClient):
 
             - DeepSeek-V3-0324 模型 | 输入：0.002元/千token | 输出：0.008元/千token
 
+            - DeepSeek-V3.1 模型 | 输入：0.004元/千token | 输出：0.012元/千token
+
 
         ### Openai兼容协议接口
         知识引擎原子能力大模型对话 API 兼容了 OpenAI 的接口规范，这意味着您可以直接使用 OpenAI 官方提供的 SDK 来调用大模型对话接口。您仅需要将 base_url 和 [api_key](https://cloud.tencent.com/document/product/1772/115970) 替换成相关配置，不需要对应用做额外修改，即可无缝将您的应用切换到相应的大模型。请参考文档：[Deepseek OpenAI对话接口](https://cloud.tencent.com/document/product/1772/115969)。
