@@ -27,7 +27,7 @@ class MongodbClient(AbstractClient):
 
 
     def AssignProject(self, request):
-        """本接口（AssignProject）用于指定云数据库实例的所属项目。
+        r"""本接口（AssignProject）用于指定云数据库实例的所属项目。
 
         :param request: Request instance for AssignProject.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.AssignProjectRequest`
@@ -50,7 +50,7 @@ class MongodbClient(AbstractClient):
 
 
     def CreateDBInstance(self, request):
-        """本接口(CreateDBInstance)用于创建包年包月的MongoDB云数据库实例。
+        r"""本接口(CreateDBInstance)用于创建包年包月的MongoDB云数据库实例。
 
         :param request: Request instance for CreateDBInstance.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.CreateDBInstanceRequest`
@@ -73,7 +73,7 @@ class MongodbClient(AbstractClient):
 
 
     def CreateDBInstanceHour(self, request):
-        """本接口(CreateDBInstanceHour)用于创建按量计费的MongoDB云数据库实例，可通过传入实例规格、实例类型、MongoDB版本、购买时长和数量等信息创建云数据库实例。
+        r"""本接口(CreateDBInstanceHour)用于创建按量计费的MongoDB云数据库实例，可通过传入实例规格、实例类型、MongoDB版本、购买时长和数量等信息创建云数据库实例。
 
         :param request: Request instance for CreateDBInstanceHour.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.CreateDBInstanceHourRequest`
@@ -96,7 +96,7 @@ class MongodbClient(AbstractClient):
 
 
     def DescribeClientConnections(self, request):
-        """本接口(DescribeClientConnections)用于查询实例客户端连接信息，包括连接IP和连接数量。目前只支持3.2版本的MongoDB实例。
+        r"""本接口(DescribeClientConnections)用于查询实例客户端连接信息，包括连接IP和连接数量。目前只支持3.2版本的MongoDB实例。
 
         :param request: Request instance for DescribeClientConnections.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.DescribeClientConnectionsRequest`
@@ -119,7 +119,7 @@ class MongodbClient(AbstractClient):
 
 
     def DescribeDBInstances(self, request):
-        """本接口(DescribeDBInstances)用于查询云数据库实例列表，支持通过项目ID、实例ID、实例状态等过滤条件来筛选实例。支持查询主实例、灾备实例和只读实例信息列表。
+        r"""本接口(DescribeDBInstances)用于查询云数据库实例列表，支持通过项目ID、实例ID、实例状态等过滤条件来筛选实例。支持查询主实例、灾备实例和只读实例信息列表。
 
         :param request: Request instance for DescribeDBInstances.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.DescribeDBInstancesRequest`
@@ -142,7 +142,7 @@ class MongodbClient(AbstractClient):
 
 
     def DescribeSlowLog(self, request):
-        """本接口(DescribeSlowLogs)用于获取云数据库实例的慢查询日志。
+        r"""本接口(DescribeSlowLogs)用于获取云数据库实例的慢查询日志。
 
         :param request: Request instance for DescribeSlowLog.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.DescribeSlowLogRequest`
@@ -165,7 +165,7 @@ class MongodbClient(AbstractClient):
 
 
     def DescribeSpecInfo(self, request):
-        """本接口(DescribeSpecInfo)用于查询实例的售卖规格。
+        r"""本接口(DescribeSpecInfo)用于查询实例的售卖规格。
 
         :param request: Request instance for DescribeSpecInfo.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.DescribeSpecInfoRequest`
@@ -188,7 +188,7 @@ class MongodbClient(AbstractClient):
 
 
     def RenameInstance(self, request):
-        """本接口(RenameInstance)用于修改云数据库实例的名称。
+        r"""本接口(RenameInstance)用于修改云数据库实例的名称。
 
         :param request: Request instance for RenameInstance.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.RenameInstanceRequest`
@@ -211,7 +211,7 @@ class MongodbClient(AbstractClient):
 
 
     def SetAutoRenew(self, request):
-        """本接口(SetAutoRenew)用于设置包年包月云数据库实例的续费选项。
+        r"""本接口(SetAutoRenew)用于设置包年包月云数据库实例的续费选项。
 
         :param request: Request instance for SetAutoRenew.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.SetAutoRenewRequest`
@@ -234,7 +234,7 @@ class MongodbClient(AbstractClient):
 
 
     def SetPassword(self, request):
-        """本接口(SetPassword)用于设置（初始化）MongoDB云数据库实例账户密码。
+        r"""本接口(SetPassword)用于设置（初始化）MongoDB云数据库实例账户密码。
 
         :param request: Request instance for SetPassword.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.SetPasswordRequest`
@@ -257,7 +257,7 @@ class MongodbClient(AbstractClient):
 
 
     def TerminateDBInstance(self, request):
-        """本接口(TerminateDBInstance)用于销毁按量计费的MongoDB云数据库实例。
+        r"""本接口(TerminateDBInstance)用于销毁按量计费的MongoDB云数据库实例。
 
         :param request: Request instance for TerminateDBInstance.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.TerminateDBInstanceRequest`
@@ -280,7 +280,7 @@ class MongodbClient(AbstractClient):
 
 
     def UpgradeDBInstance(self, request):
-        """本接口(UpgradeDBInstance)用于升级包年包月的MongoDB云数据库实例，可以扩容内存、存储以及Oplog
+        r"""本接口(UpgradeDBInstance)用于升级包年包月的MongoDB云数据库实例，可以扩容内存、存储以及Oplog
 
         :param request: Request instance for UpgradeDBInstance.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.UpgradeDBInstanceRequest`
@@ -303,7 +303,7 @@ class MongodbClient(AbstractClient):
 
 
     def UpgradeDBInstanceHour(self, request):
-        """本接口(UpgradeDBInstanceHour)用于升级按量计费的MongoDB云数据库实例，可以扩容内存、存储以及oplog
+        r"""本接口(UpgradeDBInstanceHour)用于升级按量计费的MongoDB云数据库实例，可以扩容内存、存储以及oplog
 
         :param request: Request instance for UpgradeDBInstanceHour.
         :type request: :class:`tencentcloud.mongodb.v20180408.models.UpgradeDBInstanceHourRequest`
