@@ -27,7 +27,7 @@ class SsmClient(AbstractClient):
 
 
     def CreateProductSecret(self, request):
-        """创建云产品凭据
+        r"""创建云产品凭据
 
         :param request: Request instance for CreateProductSecret.
         :type request: :class:`tencentcloud.ssm.v20190923.models.CreateProductSecretRequest`
@@ -50,7 +50,7 @@ class SsmClient(AbstractClient):
 
 
     def CreateSSHKeyPairSecret(self, request):
-        """创建用于托管SSH密钥对的凭据
+        r"""创建用于托管SSH密钥对的凭据
 
         :param request: Request instance for CreateSSHKeyPairSecret.
         :type request: :class:`tencentcloud.ssm.v20190923.models.CreateSSHKeyPairSecretRequest`
@@ -73,7 +73,7 @@ class SsmClient(AbstractClient):
 
 
     def CreateSecret(self, request):
-        """创建新的凭据信息，通过KMS进行加密保护。每个Region最多可创建存储1000个凭据信息。
+        r"""创建新的凭据信息，通过KMS进行加密保护。每个Region最多可创建存储1000个凭据信息。
 
         :param request: Request instance for CreateSecret.
         :type request: :class:`tencentcloud.ssm.v20190923.models.CreateSecretRequest`
@@ -96,7 +96,7 @@ class SsmClient(AbstractClient):
 
 
     def DeleteSecret(self, request):
-        """删除指定的凭据信息，可以通过RecoveryWindowInDays参数设置立即删除或者计划删除。对于计划删除的凭据，在删除日期到达之前状态为 PendingDelete，并可以通过RestoreSecret 进行恢复，超出指定删除日期之后会被彻底删除。您必须先通过 DisableSecret 停用凭据后才可以进行（计划）删除操作。
+        r"""删除指定的凭据信息，可以通过RecoveryWindowInDays参数设置立即删除或者计划删除。对于计划删除的凭据，在删除日期到达之前状态为 PendingDelete，并可以通过RestoreSecret 进行恢复，超出指定删除日期之后会被彻底删除。您必须先通过 DisableSecret 停用凭据后才可以进行（计划）删除操作。
 
         :param request: Request instance for DeleteSecret.
         :type request: :class:`tencentcloud.ssm.v20190923.models.DeleteSecretRequest`
@@ -119,7 +119,7 @@ class SsmClient(AbstractClient):
 
 
     def DeleteSecretVersion(self, request):
-        """该接口用于直接删除指定凭据下的单个版本凭据，删除操作立即生效，对所有状态下的凭据版本都可以删除。
+        r"""该接口用于直接删除指定凭据下的单个版本凭据，删除操作立即生效，对所有状态下的凭据版本都可以删除。
         本接口仅适用于用户自定义凭据，本接口不能对云产品凭据进行操作。
 
         :param request: Request instance for DeleteSecretVersion.
@@ -143,7 +143,7 @@ class SsmClient(AbstractClient):
 
 
     def DescribeAsyncRequestInfo(self, request):
-        """查询异步任务的执行结果
+        r"""查询异步任务的执行结果
 
         :param request: Request instance for DescribeAsyncRequestInfo.
         :type request: :class:`tencentcloud.ssm.v20190923.models.DescribeAsyncRequestInfoRequest`
@@ -166,7 +166,7 @@ class SsmClient(AbstractClient):
 
 
     def DescribeRotationDetail(self, request):
-        """查询凭据轮转策略详情。
+        r"""查询凭据轮转策略详情。
         本接口只适用于云产品凭据。
 
         :param request: Request instance for DescribeRotationDetail.
@@ -190,7 +190,7 @@ class SsmClient(AbstractClient):
 
 
     def DescribeRotationHistory(self, request):
-        """查询凭据轮转历史版本。
+        r"""查询凭据轮转历史版本。
         本接口仅适用于云产品凭据。
 
         :param request: Request instance for DescribeRotationHistory.
@@ -214,7 +214,7 @@ class SsmClient(AbstractClient):
 
 
     def DescribeSecret(self, request):
-        """获取凭据的详细属性信息。
+        r"""获取凭据的详细属性信息。
 
         :param request: Request instance for DescribeSecret.
         :type request: :class:`tencentcloud.ssm.v20190923.models.DescribeSecretRequest`
@@ -237,7 +237,7 @@ class SsmClient(AbstractClient):
 
 
     def DescribeSupportedProducts(self, request):
-        """查询支持的云产品列表
+        r"""查询支持的云产品列表
 
         :param request: Request instance for DescribeSupportedProducts.
         :type request: :class:`tencentcloud.ssm.v20190923.models.DescribeSupportedProductsRequest`
@@ -260,7 +260,7 @@ class SsmClient(AbstractClient):
 
 
     def DisableSecret(self, request):
-        """停用指定的凭据，停用后状态为 Disabled，无法通过接口获取该凭据的明文。
+        r"""停用指定的凭据，停用后状态为 Disabled，无法通过接口获取该凭据的明文。
 
         :param request: Request instance for DisableSecret.
         :type request: :class:`tencentcloud.ssm.v20190923.models.DisableSecretRequest`
@@ -283,7 +283,7 @@ class SsmClient(AbstractClient):
 
 
     def EnableSecret(self, request):
-        """该接口用于开启凭据，状态为Enabled。可以通过 GetSecretValue 接口获取凭据明文。处于PendingDelete状态的凭据不能直接开启，需要通过RestoreSecret 恢复后再开启使用。
+        r"""该接口用于开启凭据，状态为Enabled。可以通过 GetSecretValue 接口获取凭据明文。处于PendingDelete状态的凭据不能直接开启，需要通过RestoreSecret 恢复后再开启使用。
 
         :param request: Request instance for EnableSecret.
         :type request: :class:`tencentcloud.ssm.v20190923.models.EnableSecretRequest`
@@ -306,7 +306,7 @@ class SsmClient(AbstractClient):
 
 
     def GetRegions(self, request):
-        """获取控制台展示region列表
+        r"""获取控制台展示region列表
 
         :param request: Request instance for GetRegions.
         :type request: :class:`tencentcloud.ssm.v20190923.models.GetRegionsRequest`
@@ -329,7 +329,7 @@ class SsmClient(AbstractClient):
 
 
     def GetSSHKeyPairValue(self, request):
-        """获取SSH密钥对凭据明文信息。
+        r"""获取SSH密钥对凭据明文信息。
 
         :param request: Request instance for GetSSHKeyPairValue.
         :type request: :class:`tencentcloud.ssm.v20190923.models.GetSSHKeyPairValueRequest`
@@ -352,7 +352,7 @@ class SsmClient(AbstractClient):
 
 
     def GetSecretValue(self, request):
-        """对于用户自定义凭据，通过指定凭据名称和版本来获取凭据的明文信息；
+        r"""对于用户自定义凭据，通过指定凭据名称和版本来获取凭据的明文信息；
         对于云产品凭据如Mysql凭据，通过指定凭据名称和历史版本号来获取历史轮转凭据的明文信息，如果要获取当前正在使用的凭据版本的明文，需要将版本号指定为：SSM_Current。
 
         :param request: Request instance for GetSecretValue.
@@ -376,7 +376,7 @@ class SsmClient(AbstractClient):
 
 
     def GetServiceStatus(self, request):
-        """该接口用户获取用户SecretsManager服务开通状态。
+        r"""该接口用户获取用户SecretsManager服务开通状态。
 
         :param request: Request instance for GetServiceStatus.
         :type request: :class:`tencentcloud.ssm.v20190923.models.GetServiceStatusRequest`
@@ -399,7 +399,7 @@ class SsmClient(AbstractClient):
 
 
     def ListSecretVersionIds(self, request):
-        """该接口用于获取指定凭据下的版本列表信息
+        r"""该接口用于获取指定凭据下的版本列表信息
 
         :param request: Request instance for ListSecretVersionIds.
         :type request: :class:`tencentcloud.ssm.v20190923.models.ListSecretVersionIdsRequest`
@@ -422,7 +422,7 @@ class SsmClient(AbstractClient):
 
 
     def ListSecrets(self, request):
-        """该接口用于获取所有凭据的详细列表，可以指定过滤字段、排序方式等。
+        r"""该接口用于获取所有凭据的详细列表，可以指定过滤字段、排序方式等。
 
         :param request: Request instance for ListSecrets.
         :type request: :class:`tencentcloud.ssm.v20190923.models.ListSecretsRequest`
@@ -445,7 +445,7 @@ class SsmClient(AbstractClient):
 
 
     def PutSecretValue(self, request):
-        """该接口在指定名称的凭据下增加新版本的凭据内容，一个凭据下最多可以支持10个版本。只能对处于Enabled 和 Disabled 状态的凭据添加新的版本。
+        r"""该接口在指定名称的凭据下增加新版本的凭据内容，一个凭据下最多可以支持10个版本。只能对处于Enabled 和 Disabled 状态的凭据添加新的版本。
         本接口仅适用于用户自定义凭据，对云产品凭据不能操作。
 
         :param request: Request instance for PutSecretValue.
@@ -469,7 +469,7 @@ class SsmClient(AbstractClient):
 
 
     def RestoreSecret(self, request):
-        """该接口用于恢复计划删除（PendingDelete状态）中的凭据，取消计划删除。取消计划删除的凭据将处于Disabled 状态，如需恢复使用，通过EnableSecret 接口开启凭据。
+        r"""该接口用于恢复计划删除（PendingDelete状态）中的凭据，取消计划删除。取消计划删除的凭据将处于Disabled 状态，如需恢复使用，通过EnableSecret 接口开启凭据。
 
         :param request: Request instance for RestoreSecret.
         :type request: :class:`tencentcloud.ssm.v20190923.models.RestoreSecretRequest`
@@ -492,7 +492,7 @@ class SsmClient(AbstractClient):
 
 
     def RotateProductSecret(self, request):
-        """轮转云产品凭据或云API密钥对凭据。
+        r"""轮转云产品凭据或云API密钥对凭据。
         该接口仅适用于处于Enabled状态的云产品凭据或处于Enable状态的云API密钥对凭据，对于其他状态的云产品凭据或云API密钥对凭据或用户自定义凭据不适用。
 
         :param request: Request instance for RotateProductSecret.
@@ -516,7 +516,7 @@ class SsmClient(AbstractClient):
 
 
     def UpdateDescription(self, request):
-        """该接口用于修改指定凭据的描述信息，仅能修改Enabled 和 Disabled 状态的凭据。
+        r"""该接口用于修改指定凭据的描述信息，仅能修改Enabled 和 Disabled 状态的凭据。
 
         :param request: Request instance for UpdateDescription.
         :type request: :class:`tencentcloud.ssm.v20190923.models.UpdateDescriptionRequest`
@@ -539,7 +539,7 @@ class SsmClient(AbstractClient):
 
 
     def UpdateRotationStatus(self, request):
-        """设置云产品凭据轮转策略，可以设置：
+        r"""设置云产品凭据轮转策略，可以设置：
         是否开启轮转
         轮转周期
         轮转开始时间
@@ -565,7 +565,7 @@ class SsmClient(AbstractClient):
 
 
     def UpdateSecret(self, request):
-        """该接口用于更新指定凭据名称和版本号的内容，调用该接口会对新的凭据内容加密后覆盖旧的内容。仅允许更新Enabled 和 Disabled 状态的凭据。
+        r"""该接口用于更新指定凭据名称和版本号的内容，调用该接口会对新的凭据内容加密后覆盖旧的内容。仅允许更新Enabled 和 Disabled 状态的凭据。
         本接口仅适用于用户自定义凭据，不能对云产品凭据操作。
 
         :param request: Request instance for UpdateSecret.
