@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ from tencentcloud.common.abstract_model import AbstractModel
 
 
 class DetailResults(AbstractModel):
-    """文本审核返回的详细结果
+    r"""文本审核返回的详细结果
 
     """
 
@@ -28,31 +28,23 @@ class DetailResults(AbstractModel):
         :param _Label: 该字段用于返回检测结果所对应的全部恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
         :type Label: str
         :param _Suggestion: 该字段用于返回对应当前标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
-注意：此字段可能返回 null，表示取不到有效值。
         :type Suggestion: str
         :param _Keywords: 该字段用于返回检测文本命中的关键词信息，用于标注文本违规的具体原因（如：*加我微信*）。该参数可能会有多个返回值，代表命中的多个关键词；如返回值为空且Score不为空，则代表识别结果所对应的恶意标签（Label）是来自于语义模型判断的返回值。
-注意：此字段可能返回 null，表示取不到有效值。
         :type Keywords: list of str
         :param _Score: 该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容。
-注意：此字段可能返回 null，表示取不到有效值。
         :type Score: int
         :param _LibType: 该字段用于返回自定义关键词对应的词库类型，取值为**1**（黑白库）和**2**（自定义关键词库），若未配置自定义关键词库,则默认值为1（黑白库匹配）。
-注意：此字段可能返回 null，表示取不到有效值。
         :type LibType: int
         :param _LibId: 该字段用于返回自定义库的ID，以方便自定义库管理和配置。
-注意：此字段可能返回 null，表示取不到有效值。
         :type LibId: str
         :param _LibName: 该字段用于返回自定义库的名称,以方便自定义库管理和配置。
-注意：此字段可能返回 null，表示取不到有效值。
         :type LibName: str
         :param _SubLabel: 该字段用于返回当前标签（Label）下的二级标签。
-注意：此字段可能返回 null，表示取不到有效值。
         :type SubLabel: str
         :param _Tags: 该字段用于返回当前一级标签（Label）下的关键词、子标签及分数。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Tags: list of Tag
         :param _HitInfos: 该字段用于返回违规文本命中信息
-注意：此字段可能返回 null，表示取不到有效值。
         :type HitInfos: list of HitInfo
         """
         self._Label = None
@@ -68,7 +60,7 @@ class DetailResults(AbstractModel):
 
     @property
     def Label(self):
-        """该字段用于返回检测结果所对应的全部恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
+        r"""该字段用于返回检测结果所对应的全部恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
         :rtype: str
         """
         return self._Label
@@ -79,8 +71,7 @@ class DetailResults(AbstractModel):
 
     @property
     def Suggestion(self):
-        """该字段用于返回对应当前标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回对应当前标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
         :rtype: str
         """
         return self._Suggestion
@@ -91,8 +82,7 @@ class DetailResults(AbstractModel):
 
     @property
     def Keywords(self):
-        """该字段用于返回检测文本命中的关键词信息，用于标注文本违规的具体原因（如：*加我微信*）。该参数可能会有多个返回值，代表命中的多个关键词；如返回值为空且Score不为空，则代表识别结果所对应的恶意标签（Label）是来自于语义模型判断的返回值。
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回检测文本命中的关键词信息，用于标注文本违规的具体原因（如：*加我微信*）。该参数可能会有多个返回值，代表命中的多个关键词；如返回值为空且Score不为空，则代表识别结果所对应的恶意标签（Label）是来自于语义模型判断的返回值。
         :rtype: list of str
         """
         return self._Keywords
@@ -103,8 +93,7 @@ class DetailResults(AbstractModel):
 
     @property
     def Score(self):
-        """该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容。
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容。
         :rtype: int
         """
         return self._Score
@@ -115,8 +104,7 @@ class DetailResults(AbstractModel):
 
     @property
     def LibType(self):
-        """该字段用于返回自定义关键词对应的词库类型，取值为**1**（黑白库）和**2**（自定义关键词库），若未配置自定义关键词库,则默认值为1（黑白库匹配）。
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回自定义关键词对应的词库类型，取值为**1**（黑白库）和**2**（自定义关键词库），若未配置自定义关键词库,则默认值为1（黑白库匹配）。
         :rtype: int
         """
         return self._LibType
@@ -127,8 +115,7 @@ class DetailResults(AbstractModel):
 
     @property
     def LibId(self):
-        """该字段用于返回自定义库的ID，以方便自定义库管理和配置。
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回自定义库的ID，以方便自定义库管理和配置。
         :rtype: str
         """
         return self._LibId
@@ -139,8 +126,7 @@ class DetailResults(AbstractModel):
 
     @property
     def LibName(self):
-        """该字段用于返回自定义库的名称,以方便自定义库管理和配置。
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回自定义库的名称,以方便自定义库管理和配置。
         :rtype: str
         """
         return self._LibName
@@ -151,8 +137,7 @@ class DetailResults(AbstractModel):
 
     @property
     def SubLabel(self):
-        """该字段用于返回当前标签（Label）下的二级标签。
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回当前标签（Label）下的二级标签。
         :rtype: str
         """
         return self._SubLabel
@@ -163,7 +148,7 @@ class DetailResults(AbstractModel):
 
     @property
     def Tags(self):
-        """该字段用于返回当前一级标签（Label）下的关键词、子标签及分数。
+        r"""该字段用于返回当前一级标签（Label）下的关键词、子标签及分数。
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: list of Tag
         """
@@ -175,8 +160,7 @@ class DetailResults(AbstractModel):
 
     @property
     def HitInfos(self):
-        """该字段用于返回违规文本命中信息
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回违规文本命中信息
         :rtype: list of HitInfo
         """
         return self._HitInfos
@@ -218,7 +202,7 @@ class DetailResults(AbstractModel):
 
 
 class Device(AbstractModel):
-    """用于表示业务用户对应的设备信息
+    r"""用于表示业务用户对应的设备信息
 
     """
 
@@ -251,7 +235,7 @@ class Device(AbstractModel):
 
     @property
     def IP(self):
-        """该字段表示业务用户对应设备的IP地址。<br>
+        r"""该字段表示业务用户对应设备的IP地址。<br>
 备注:目前仅支持IPv4地址记录，不支持IPv6地址记录。
         :rtype: str
         """
@@ -263,7 +247,7 @@ class Device(AbstractModel):
 
     @property
     def Mac(self):
-        """该字段表示业务用户对应的MAC地址，以方便设备识别与管理；其格式与取值与标准MAC地址一致。
+        r"""该字段表示业务用户对应的MAC地址，以方便设备识别与管理；其格式与取值与标准MAC地址一致。
         :rtype: str
         """
         return self._Mac
@@ -274,7 +258,7 @@ class Device(AbstractModel):
 
     @property
     def TokenId(self):
-        """*内测中，敬请期待。*
+        r"""*内测中，敬请期待。*
         :rtype: str
         """
         return self._TokenId
@@ -285,7 +269,7 @@ class Device(AbstractModel):
 
     @property
     def DeviceId(self):
-        """*内测中，敬请期待。*
+        r"""*内测中，敬请期待。*
         :rtype: str
         """
         return self._DeviceId
@@ -296,7 +280,7 @@ class Device(AbstractModel):
 
     @property
     def IMEI(self):
-        """该字段表示业务用户对应设备的**IMEI码**（国际移动设备识别码），该识别码可用于识别每一部独立的手机等移动通信设备，方便设备识别与管理。<br>备注：格式为**15-17位纯数字**。
+        r"""该字段表示业务用户对应设备的**IMEI码**（国际移动设备识别码），该识别码可用于识别每一部独立的手机等移动通信设备，方便设备识别与管理。<br>备注：格式为**15-17位纯数字**。
         :rtype: str
         """
         return self._IMEI
@@ -307,7 +291,7 @@ class Device(AbstractModel):
 
     @property
     def IDFA(self):
-        """**iOS设备专用**，该字段表示业务用户对应的**IDFA**(广告标识符),这是由苹果公司提供的用于标识用户的广告标识符，由一串16进制的32位数字和字母组成。<br>
+        r"""**iOS设备专用**，该字段表示业务用户对应的**IDFA**(广告标识符),这是由苹果公司提供的用于标识用户的广告标识符，由一串16进制的32位数字和字母组成。<br>
 备注：苹果公司自2021年iOS14更新后允许用户手动关闭或者开启IDFA，故此字符串标记有效性可能有所降低。
         :rtype: str
         """
@@ -319,7 +303,7 @@ class Device(AbstractModel):
 
     @property
     def IDFV(self):
-        """**iOS设备专用**，该字段表示业务用户对应的**IDFV**(应用开发商标识符),这是由苹果公司提供的用于标注应用开发商的标识符，由一串16进制的32位数字和字母组成，可被用于唯一标识设备。
+        r"""**iOS设备专用**，该字段表示业务用户对应的**IDFV**(应用开发商标识符),这是由苹果公司提供的用于标注应用开发商的标识符，由一串16进制的32位数字和字母组成，可被用于唯一标识设备。
         :rtype: str
         """
         return self._IDFV
@@ -348,23 +332,19 @@ class Device(AbstractModel):
 
 
 class HitInfo(AbstractModel):
-    """关键词命中位置信息
+    r"""关键词命中位置信息
 
     """
 
     def __init__(self):
         r"""
         :param _Type: 标识模型命中还是关键词命中
-注意：此字段可能返回 null，表示取不到有效值。
         :type Type: str
         :param _Keyword: 命中关键词
-注意：此字段可能返回 null，表示取不到有效值。
         :type Keyword: str
         :param _LibName: 自定义词库名称
-注意：此字段可能返回 null，表示取不到有效值。
         :type LibName: str
         :param _Positions: 位置信息
-注意：此字段可能返回 null，表示取不到有效值。
         :type Positions: list of Positions
         """
         self._Type = None
@@ -374,8 +354,7 @@ class HitInfo(AbstractModel):
 
     @property
     def Type(self):
-        """标识模型命中还是关键词命中
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""标识模型命中还是关键词命中
         :rtype: str
         """
         return self._Type
@@ -386,8 +365,7 @@ class HitInfo(AbstractModel):
 
     @property
     def Keyword(self):
-        """命中关键词
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""命中关键词
         :rtype: str
         """
         return self._Keyword
@@ -398,8 +376,7 @@ class HitInfo(AbstractModel):
 
     @property
     def LibName(self):
-        """自定义词库名称
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""自定义词库名称
         :rtype: str
         """
         return self._LibName
@@ -410,8 +387,7 @@ class HitInfo(AbstractModel):
 
     @property
     def Positions(self):
-        """位置信息
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""位置信息
         :rtype: list of Positions
         """
         return self._Positions
@@ -442,17 +418,15 @@ class HitInfo(AbstractModel):
 
 
 class Positions(AbstractModel):
-    """标识命中的违规关键词位置信息
+    r"""标识命中的违规关键词位置信息
 
     """
 
     def __init__(self):
         r"""
         :param _Start: 关键词起始位置
-注意：此字段可能返回 null，表示取不到有效值。
         :type Start: int
         :param _End: 关键词结束位置
-注意：此字段可能返回 null，表示取不到有效值。
         :type End: int
         """
         self._Start = None
@@ -460,8 +434,7 @@ class Positions(AbstractModel):
 
     @property
     def Start(self):
-        """关键词起始位置
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""关键词起始位置
         :rtype: int
         """
         return self._Start
@@ -472,8 +445,7 @@ class Positions(AbstractModel):
 
     @property
     def End(self):
-        """关键词结束位置
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""关键词结束位置
         :rtype: int
         """
         return self._End
@@ -497,7 +469,7 @@ class Positions(AbstractModel):
 
 
 class RiskDetails(AbstractModel):
-    """账号风险检测结果
+    r"""账号风险检测结果
 
     """
 
@@ -513,7 +485,7 @@ class RiskDetails(AbstractModel):
 
     @property
     def Label(self):
-        """该字段用于返回账号信息检测对应的风险类别，取值为：**RiskAccount**（账号存在风险）、**RiskIP**（IP地址存在风险）、**RiskIMEI**（移动设备识别码存在风险）。
+        r"""该字段用于返回账号信息检测对应的风险类别，取值为：**RiskAccount**（账号存在风险）、**RiskIP**（IP地址存在风险）、**RiskIMEI**（移动设备识别码存在风险）。
         :rtype: str
         """
         return self._Label
@@ -524,7 +496,7 @@ class RiskDetails(AbstractModel):
 
     @property
     def Level(self):
-        """该字段用于返回账号信息检测对应的风险等级，取值为：**1**（疑似存在风险）和**2**（存在恶意风险）。
+        r"""该字段用于返回账号信息检测对应的风险等级，取值为：**1**（疑似存在风险）和**2**（存在恶意风险）。
         :rtype: int
         """
         return self._Level
@@ -548,25 +520,21 @@ class RiskDetails(AbstractModel):
 
 
 class SentimentAnalysis(AbstractModel):
-    """情感分析结果
+    r"""情感分析结果
 
     """
 
     def __init__(self):
         r"""
         :param _Label: 情感标签
-注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
         :param _Score: 标签分数，取值范围0到100
-注意：此字段可能返回 null，表示取不到有效值。
         :type Score: int
         :param _Detail: 情感分析明细
-注意：此字段可能返回 null，表示取不到有效值。
         :type Detail: :class:`tencentcloud.tms.v20201229.models.SentimentDetail`
         :param _Code: 响应码，成功为"OK"，失败为"InternalError"
         :type Code: str
         :param _Message: 异常信息
-注意：此字段可能返回 null，表示取不到有效值。
         :type Message: str
         """
         self._Label = None
@@ -577,8 +545,7 @@ class SentimentAnalysis(AbstractModel):
 
     @property
     def Label(self):
-        """情感标签
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""情感标签
         :rtype: str
         """
         return self._Label
@@ -589,8 +556,7 @@ class SentimentAnalysis(AbstractModel):
 
     @property
     def Score(self):
-        """标签分数，取值范围0到100
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""标签分数，取值范围0到100
         :rtype: int
         """
         return self._Score
@@ -601,8 +567,7 @@ class SentimentAnalysis(AbstractModel):
 
     @property
     def Detail(self):
-        """情感分析明细
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""情感分析明细
         :rtype: :class:`tencentcloud.tms.v20201229.models.SentimentDetail`
         """
         return self._Detail
@@ -613,7 +578,7 @@ class SentimentAnalysis(AbstractModel):
 
     @property
     def Code(self):
-        """响应码，成功为"OK"，失败为"InternalError"
+        r"""响应码，成功为"OK"，失败为"InternalError"
         :rtype: str
         """
         return self._Code
@@ -624,8 +589,7 @@ class SentimentAnalysis(AbstractModel):
 
     @property
     def Message(self):
-        """异常信息
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""异常信息
         :rtype: str
         """
         return self._Message
@@ -654,17 +618,15 @@ class SentimentAnalysis(AbstractModel):
 
 
 class SentimentDetail(AbstractModel):
-    """情感分析明细
+    r"""情感分析明细
 
     """
 
     def __init__(self):
         r"""
         :param _Positive: 正向分数，取值范围0到100
-注意：此字段可能返回 null，表示取不到有效值。
         :type Positive: int
         :param _Negative: 负向分数，取值范围0到100
-注意：此字段可能返回 null，表示取不到有效值。
         :type Negative: int
         """
         self._Positive = None
@@ -672,8 +634,7 @@ class SentimentDetail(AbstractModel):
 
     @property
     def Positive(self):
-        """正向分数，取值范围0到100
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""正向分数，取值范围0到100
         :rtype: int
         """
         return self._Positive
@@ -684,8 +645,7 @@ class SentimentDetail(AbstractModel):
 
     @property
     def Negative(self):
-        """负向分数，取值范围0到100
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""负向分数，取值范围0到100
         :rtype: int
         """
         return self._Negative
@@ -709,20 +669,17 @@ class SentimentDetail(AbstractModel):
 
 
 class Tag(AbstractModel):
-    """该字段用于返回审核结果明细字段的标签及分数
+    r"""该字段用于返回审核结果明细字段的标签及分数
 
     """
 
     def __init__(self):
         r"""
         :param _Keyword: 该字段用于返回命中的关键词
-注意：此字段可能返回 null，表示取不到有效值。
         :type Keyword: str
         :param _SubLabel: 该字段用于返回子标签
-注意：此字段可能返回 null，表示取不到有效值。
         :type SubLabel: str
         :param _Score: 该字段用于返回子标签对应的分数
-注意：此字段可能返回 null，表示取不到有效值。
         :type Score: int
         """
         self._Keyword = None
@@ -731,8 +688,7 @@ class Tag(AbstractModel):
 
     @property
     def Keyword(self):
-        """该字段用于返回命中的关键词
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回命中的关键词
         :rtype: str
         """
         return self._Keyword
@@ -743,8 +699,7 @@ class Tag(AbstractModel):
 
     @property
     def SubLabel(self):
-        """该字段用于返回子标签
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回子标签
         :rtype: str
         """
         return self._SubLabel
@@ -755,8 +710,7 @@ class Tag(AbstractModel):
 
     @property
     def Score(self):
-        """该字段用于返回子标签对应的分数
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回子标签对应的分数
         :rtype: int
         """
         return self._Score
@@ -781,7 +735,7 @@ class Tag(AbstractModel):
 
 
 class TextModerationRequest(AbstractModel):
-    """TextModeration请求参数结构体
+    r"""TextModeration请求参数结构体
 
     """
 
@@ -789,7 +743,7 @@ class TextModerationRequest(AbstractModel):
         r"""
         :param _Content: 该字段表示待检测对象的文本内容，文本需要按utf-8格式编码，长度不能超过10000个字符（按unicode编码计算），并进行 Base64加密
         :type Content: str
-        :param _BizType: 该字段表示使用的策略的具体编号，该字段需要先在[内容安全控制台](#https://console.cloud.tencent.com/cms/clouds/manage)中配置，控制台访问地址：。
+        :param _BizType: 该字段表示使用的策略的具体编号，该字段需要先在[内容安全控制台](https://console.cloud.tencent.com/cms/clouds/manage)中配置，控制台访问地址：。
 备注：不同Biztype关联不同的业务场景与识别能力策略，调用前请确认正确的Biztype。
         :type BizType: str
         :param _DataId: 该字段表示您为待检测对象分配的数据ID，传入后可方便您对文件进行标识和管理。<br>取值：由英文字母（大小写均可）、数字及四个特殊符号（_，-，@，#）组成，**长度不超过64个字符**
@@ -798,9 +752,9 @@ class TextModerationRequest(AbstractModel):
         :type User: :class:`tencentcloud.tms.v20201229.models.User`
         :param _Device: 该字段表示待检测对象对应的设备相关信息，传入后可便于甄别相应违规风险设备
         :type Device: :class:`tencentcloud.tms.v20201229.models.Device`
-        :param _SourceLanguage: 表示Content的原始语种，枚举值包括 "en" 和 "zh"。其中，"en" 表示英文，"zh" 表示中文。非中文场景的处理耗时较高，具体情况取决于送审文本长度，非中文场景需[反馈工单](#https://console.cloud.tencent.com/workorder/category?level1_id=141&level2_id=1287&source=14&data_title=%E6%96%87%E6%9C%AC%E5%86%85%E5%AE%B9%E5%AE%89%E5%85%A8&step=1)确认。
+        :param _SourceLanguage: 表示Content的原始语种，枚举值包括 "en" 和 "zh"。其中，"en" 表示英文，"zh" 表示中文。非中文场景的处理耗时较高，具体情况取决于送审文本长度，非中文场景需[反馈工单](https://console.cloud.tencent.com/workorder/category?level1_id=141&level2_id=1287&source=14&data_title=%E6%96%87%E6%9C%AC%E5%86%85%E5%AE%B9%E5%AE%89%E5%85%A8&step=1)确认。
         :type SourceLanguage: str
-        :param _Type: 审核的业务类型，枚举值包括 "TEXT" 和 "TEXT_AIGC"。"TEXT" 表示传统文本审核，"TEXT_AIGC" 表示文本AIGC审核。
+        :param _Type: 审核的业务类型，枚举值包括"TEXT"和"TEXT_AIGC"。其中"TEXT"表示传统文本审核，"TEXT_AIGC”表示AI生成检测（生成检测能力具体能力了解可[参见文档](https://cloud.tencent.com/document/product/1124/118694)）。
         :type Type: str
         """
         self._Content = None
@@ -813,7 +767,7 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def Content(self):
-        """该字段表示待检测对象的文本内容，文本需要按utf-8格式编码，长度不能超过10000个字符（按unicode编码计算），并进行 Base64加密
+        r"""该字段表示待检测对象的文本内容，文本需要按utf-8格式编码，长度不能超过10000个字符（按unicode编码计算），并进行 Base64加密
         :rtype: str
         """
         return self._Content
@@ -824,7 +778,7 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def BizType(self):
-        """该字段表示使用的策略的具体编号，该字段需要先在[内容安全控制台](#https://console.cloud.tencent.com/cms/clouds/manage)中配置，控制台访问地址：。
+        r"""该字段表示使用的策略的具体编号，该字段需要先在[内容安全控制台](https://console.cloud.tencent.com/cms/clouds/manage)中配置，控制台访问地址：。
 备注：不同Biztype关联不同的业务场景与识别能力策略，调用前请确认正确的Biztype。
         :rtype: str
         """
@@ -836,7 +790,7 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def DataId(self):
-        """该字段表示您为待检测对象分配的数据ID，传入后可方便您对文件进行标识和管理。<br>取值：由英文字母（大小写均可）、数字及四个特殊符号（_，-，@，#）组成，**长度不超过64个字符**
+        r"""该字段表示您为待检测对象分配的数据ID，传入后可方便您对文件进行标识和管理。<br>取值：由英文字母（大小写均可）、数字及四个特殊符号（_，-，@，#）组成，**长度不超过64个字符**
         :rtype: str
         """
         return self._DataId
@@ -847,7 +801,7 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def User(self):
-        """该字段表示待检测对象对应的用户相关信息，传入后可便于甄别相应违规风险用户
+        r"""该字段表示待检测对象对应的用户相关信息，传入后可便于甄别相应违规风险用户
         :rtype: :class:`tencentcloud.tms.v20201229.models.User`
         """
         return self._User
@@ -858,7 +812,7 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def Device(self):
-        """该字段表示待检测对象对应的设备相关信息，传入后可便于甄别相应违规风险设备
+        r"""该字段表示待检测对象对应的设备相关信息，传入后可便于甄别相应违规风险设备
         :rtype: :class:`tencentcloud.tms.v20201229.models.Device`
         """
         return self._Device
@@ -869,7 +823,7 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def SourceLanguage(self):
-        """表示Content的原始语种，枚举值包括 "en" 和 "zh"。其中，"en" 表示英文，"zh" 表示中文。非中文场景的处理耗时较高，具体情况取决于送审文本长度，非中文场景需[反馈工单](#https://console.cloud.tencent.com/workorder/category?level1_id=141&level2_id=1287&source=14&data_title=%E6%96%87%E6%9C%AC%E5%86%85%E5%AE%B9%E5%AE%89%E5%85%A8&step=1)确认。
+        r"""表示Content的原始语种，枚举值包括 "en" 和 "zh"。其中，"en" 表示英文，"zh" 表示中文。非中文场景的处理耗时较高，具体情况取决于送审文本长度，非中文场景需[反馈工单](https://console.cloud.tencent.com/workorder/category?level1_id=141&level2_id=1287&source=14&data_title=%E6%96%87%E6%9C%AC%E5%86%85%E5%AE%B9%E5%AE%89%E5%85%A8&step=1)确认。
         :rtype: str
         """
         return self._SourceLanguage
@@ -880,7 +834,7 @@ class TextModerationRequest(AbstractModel):
 
     @property
     def Type(self):
-        """审核的业务类型，枚举值包括 "TEXT" 和 "TEXT_AIGC"。"TEXT" 表示传统文本审核，"TEXT_AIGC" 表示文本AIGC审核。
+        r"""审核的业务类型，枚举值包括"TEXT"和"TEXT_AIGC"。其中"TEXT"表示传统文本审核，"TEXT_AIGC”表示AI生成检测（生成检测能力具体能力了解可[参见文档](https://cloud.tencent.com/document/product/1124/118694)）。
         :rtype: str
         """
         return self._Type
@@ -913,7 +867,7 @@ class TextModerationRequest(AbstractModel):
 
 
 class TextModerationResponse(AbstractModel):
-    """TextModeration返回参数结构体
+    r"""TextModeration返回参数结构体
 
     """
 
@@ -937,16 +891,12 @@ class TextModerationResponse(AbstractModel):
 注意：此字段可能返回 null，表示取不到有效值。
         :type RiskDetails: list of RiskDetails
         :param _Extra: 该字段用于返回根据您的需求配置的额外附加信息（Extra），如未配置则默认返回值为空。<br>备注：不同客户或Biztype下返回信息不同，如需配置该字段请提交工单咨询或联系售后专员处理
-注意：此字段可能返回 null，表示取不到有效值。
         :type Extra: str
         :param _DataId: 该字段用于返回检测对象对应请求参数中的DataId，与输入的DataId字段中的内容对应
-注意：此字段可能返回 null，表示取不到有效值。
         :type DataId: str
         :param _SubLabel: 该字段用于返回当前标签（Label）下的二级标签。
-注意：此字段可能返回 null，表示取不到有效值。
         :type SubLabel: str
         :param _ContextText: 该字段用于返回上下文关联文本
-注意：此字段可能返回 null，表示取不到有效值。
         :type ContextText: str
         :param _SentimentAnalysis: 情感分析结果
 注意：此字段可能返回 null，表示取不到有效值。
@@ -973,7 +923,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def BizType(self):
-        """该字段用于返回请求参数中的BizType参数
+        r"""该字段用于返回请求参数中的BizType参数
         :rtype: str
         """
         return self._BizType
@@ -984,7 +934,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def Label(self):
-        """该字段用于返回检测结果（DetailResults）中所对应的**优先级最高的恶意标签**，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型
+        r"""该字段用于返回检测结果（DetailResults）中所对应的**优先级最高的恶意标签**，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型
         :rtype: str
         """
         return self._Label
@@ -995,7 +945,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def Suggestion(self):
-        """该字段用于返回后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
+        r"""该字段用于返回后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
         :rtype: str
         """
         return self._Suggestion
@@ -1006,7 +956,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def Keywords(self):
-        """该字段用于返回当前标签（Label）下被检测文本命中的关键词信息，用于标注文本违规的具体原因（如：*加我微信*）。该参数可能会有多个返回值，代表命中的多个关键词；如返回值为空且Score不为空，则代表识别结果所对应的恶意标签（Label）是来自于语义模型判断的返回值
+        r"""该字段用于返回当前标签（Label）下被检测文本命中的关键词信息，用于标注文本违规的具体原因（如：*加我微信*）。该参数可能会有多个返回值，代表命中的多个关键词；如返回值为空且Score不为空，则代表识别结果所对应的恶意标签（Label）是来自于语义模型判断的返回值
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: list of str
         """
@@ -1018,7 +968,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def Score(self):
-        """该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容
+        r"""该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容
         :rtype: int
         """
         return self._Score
@@ -1029,7 +979,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def DetailResults(self):
-        """该字段用于返回基于文本风险库审核的详细结果，返回值信息可参阅对应数据结构（DetailResults）的详细描述
+        r"""该字段用于返回基于文本风险库审核的详细结果，返回值信息可参阅对应数据结构（DetailResults）的详细描述
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: list of DetailResults
         """
@@ -1041,7 +991,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def RiskDetails(self):
-        """该字段用于返回文本检测中存在违规风险的账号检测结果，主要包括违规风险类别和风险等级信息，具体内容可参阅对应数据结构（RiskDetails）的详细描述
+        r"""该字段用于返回文本检测中存在违规风险的账号检测结果，主要包括违规风险类别和风险等级信息，具体内容可参阅对应数据结构（RiskDetails）的详细描述
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: list of RiskDetails
         """
@@ -1053,8 +1003,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def Extra(self):
-        """该字段用于返回根据您的需求配置的额外附加信息（Extra），如未配置则默认返回值为空。<br>备注：不同客户或Biztype下返回信息不同，如需配置该字段请提交工单咨询或联系售后专员处理
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回根据您的需求配置的额外附加信息（Extra），如未配置则默认返回值为空。<br>备注：不同客户或Biztype下返回信息不同，如需配置该字段请提交工单咨询或联系售后专员处理
         :rtype: str
         """
         return self._Extra
@@ -1065,8 +1014,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def DataId(self):
-        """该字段用于返回检测对象对应请求参数中的DataId，与输入的DataId字段中的内容对应
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回检测对象对应请求参数中的DataId，与输入的DataId字段中的内容对应
         :rtype: str
         """
         return self._DataId
@@ -1077,8 +1025,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def SubLabel(self):
-        """该字段用于返回当前标签（Label）下的二级标签。
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回当前标签（Label）下的二级标签。
         :rtype: str
         """
         return self._SubLabel
@@ -1089,8 +1036,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def ContextText(self):
-        """该字段用于返回上下文关联文本
-注意：此字段可能返回 null，表示取不到有效值。
+        r"""该字段用于返回上下文关联文本
         :rtype: str
         """
         return self._ContextText
@@ -1101,7 +1047,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def SentimentAnalysis(self):
-        """情感分析结果
+        r"""情感分析结果
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: :class:`tencentcloud.tms.v20201229.models.SentimentAnalysis`
         """
@@ -1113,7 +1059,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def HitType(self):
-        """该字段用于标识本次审核决策归因，比如text_nlp_tianji标识是由nlp tianji模型给出的审核决策，text_keyword_public标识命中了业务的关键词库
+        r"""该字段用于标识本次审核决策归因，比如text_nlp_tianji标识是由nlp tianji模型给出的审核决策，text_keyword_public标识命中了业务的关键词库
         :rtype: str
         """
         return self._HitType
@@ -1124,7 +1070,7 @@ class TextModerationResponse(AbstractModel):
 
     @property
     def RequestId(self):
-        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        r"""唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :rtype: str
         """
         return self._RequestId
@@ -1164,7 +1110,7 @@ class TextModerationResponse(AbstractModel):
 
 
 class User(AbstractModel):
-    """用于表示业务用户的账号相关信息
+    r"""用于表示业务用户的账号相关信息
 
     """
 
@@ -1217,7 +1163,7 @@ class User(AbstractModel):
 
     @property
     def UserId(self):
-        """该字段表示业务用户ID,填写后，系统可根据账号过往违规历史优化审核结果判定，有利于存在可疑违规风险时的辅助判断。<br>
+        r"""该字段表示业务用户ID,填写后，系统可根据账号过往违规历史优化审核结果判定，有利于存在可疑违规风险时的辅助判断。<br>
 备注：该字段可传入微信openid、QQopenid、字符串等账号信息，与账号类别参数（AccountType）配合使用可确定唯一账号。
         :rtype: str
         """
@@ -1229,7 +1175,7 @@ class User(AbstractModel):
 
     @property
     def Nickname(self):
-        """该字段表示业务用户对应的账号昵称信息。
+        r"""该字段表示业务用户对应的账号昵称信息。
         :rtype: str
         """
         return self._Nickname
@@ -1240,7 +1186,7 @@ class User(AbstractModel):
 
     @property
     def AccountType(self):
-        """该字段表示业务用户ID对应的账号类型，取值：**1**-微信uin，**2**-QQ号，**3**-微信群uin，**4**-qq群号，**5**-微信openid，**6**-QQopenid，**7**-其它string。<br>
+        r"""该字段表示业务用户ID对应的账号类型，取值：**1**-微信uin，**2**-QQ号，**3**-微信群uin，**4**-qq群号，**5**-微信openid，**6**-QQopenid，**7**-其它string。<br>
 该字段与账号ID参数（UserId）配合使用可确定唯一账号。
         :rtype: int
         """
@@ -1252,7 +1198,7 @@ class User(AbstractModel):
 
     @property
     def Gender(self):
-        """该字段表示业务用户对应账号的性别信息。<br>
+        r"""该字段表示业务用户对应账号的性别信息。<br>
 取值：**0**（默认值，代表性别未知）、**1**（男性）、**2**（女性）。
         :rtype: int
         """
@@ -1264,7 +1210,7 @@ class User(AbstractModel):
 
     @property
     def Age(self):
-        """该字段表示业务用户对应账号的年龄信息。<br>
+        r"""该字段表示业务用户对应账号的年龄信息。<br>
 取值：**0**（默认值，代表年龄未知）-（**自定义年龄上限**）之间的整数。
         :rtype: int
         """
@@ -1276,7 +1222,7 @@ class User(AbstractModel):
 
     @property
     def Level(self):
-        """该字段表示业务用户对应账号的等级信息。<br>
+        r"""该字段表示业务用户对应账号的等级信息。<br>
 取值：**0**（默认值，代表等级未知）、**1**（等级较低）、**2**（等级中等）、**3**（等级较高），目前**暂不支持自定义等级**。
         :rtype: int
         """
@@ -1288,7 +1234,7 @@ class User(AbstractModel):
 
     @property
     def Phone(self):
-        """该字段表示业务用户对应账号的手机号信息，支持全球各地区手机号的记录。<br>
+        r"""该字段表示业务用户对应账号的手机号信息，支持全球各地区手机号的记录。<br>
 备注：请保持手机号格式的统一，如区号格式（086/+86）等。
         :rtype: str
         """
@@ -1300,7 +1246,7 @@ class User(AbstractModel):
 
     @property
     def HeadUrl(self):
-        """该字段表示业务用户头像图片的访问链接(URL)，支持PNG、JPG、JPEG、BMP、GIF、WEBP格式。
+        r"""该字段表示业务用户头像图片的访问链接(URL)，支持PNG、JPG、JPEG、BMP、GIF、WEBP格式。
 备注：头像图片大小不超过5MB，建议分辨率不低于256x256；图片下载时间限制为3秒，超过则会返回下载超时。
         :rtype: str
         """
@@ -1312,7 +1258,7 @@ class User(AbstractModel):
 
     @property
     def Desc(self):
-        """该字段表示业务用户的简介信息，支持汉字、英文及特殊符号，长度不超过5000个汉字字符。
+        r"""该字段表示业务用户的简介信息，支持汉字、英文及特殊符号，长度不超过5000个汉字字符。
         :rtype: str
         """
         return self._Desc
@@ -1323,7 +1269,7 @@ class User(AbstractModel):
 
     @property
     def RoomId(self):
-        """该字段表示业务群聊场景时的房间ID。
+        r"""该字段表示业务群聊场景时的房间ID。
         :rtype: str
         """
         return self._RoomId
@@ -1334,7 +1280,7 @@ class User(AbstractModel):
 
     @property
     def ReceiverId(self):
-        """该字段表示消息接受者ID
+        r"""该字段表示消息接受者ID
         :rtype: str
         """
         return self._ReceiverId
@@ -1345,7 +1291,7 @@ class User(AbstractModel):
 
     @property
     def SendTime(self):
-        """消息生成时间，精确到毫秒
+        r"""消息生成时间，精确到毫秒
         :rtype: int
         """
         return self._SendTime
