@@ -19,7 +19,7 @@ from tencentcloud.common.abstract_model import AbstractModel
 
 
 class CreateTtsTaskRequest(AbstractModel):
-    """CreateTtsTask请求参数结构体
+    r"""CreateTtsTask请求参数结构体
 
     """
 
@@ -35,7 +35,7 @@ class CreateTtsTaskRequest(AbstractModel):
         :type ProjectId: int
         :param _ModelType: 模型类型，1-默认模型。
         :type ModelType: int
-        :param _VoiceType: 音色 ID，包括标准音色与精品音色，精品音色拟真度更高，价格不同于标准音色，请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
+        :param _VoiceType: 音色 ID，价格请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
         :type VoiceType: int
         :param _PrimaryLanguage: 主语言类型：<li>1-中文（默认）</li><li>2-英文</li><li>3-日文</li>
         :type PrimaryLanguage: int
@@ -71,7 +71,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def Text(self):
-        """合成语音的源文本，按UTF-8编码统一计算，最多支持10万字符
+        r"""合成语音的源文本，按UTF-8编码统一计算，最多支持10万字符
         :rtype: str
         """
         return self._Text
@@ -82,7 +82,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def Volume(self):
-        """音量大小，范围[-10，10]，对应音量大小。默认为0，代表正常音量，值越大音量越高。
+        r"""音量大小，范围[-10，10]，对应音量大小。默认为0，代表正常音量，值越大音量越高。
         :rtype: float
         """
         return self._Volume
@@ -93,7 +93,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def Speed(self):
-        """语速，范围：[-2，6]，分别对应不同语速：<li>-2代表0.6倍</li><li>-1代表0.8倍</li><li>0代表1.0倍（默认）</li><li>1代表1.2倍</li><li>2代表1.5倍</li><li>6代表2.5倍</li>如果需要更细化的语速，可以保留小数点后 2 位，例如0.5/1.25/2.81等。<br>参数值与实际语速转换，可参考[代码示例](https://sdk-1300466766.cos.ap-shanghai.myqcloud.com/sample/speed_sample.tar.gz)
+        r"""语速，范围：[-2，6]，分别对应不同语速：<li>-2代表0.6倍</li><li>-1代表0.8倍</li><li>0代表1.0倍（默认）</li><li>1代表1.2倍</li><li>2代表1.5倍</li><li>6代表2.5倍</li>如果需要更细化的语速，可以保留小数点后 2 位，例如0.5/1.25/2.81等。<br>参数值与实际语速转换，可参考[代码示例](https://sdk-1300466766.cos.ap-shanghai.myqcloud.com/sample/speed_sample.tar.gz)
         :rtype: float
         """
         return self._Speed
@@ -104,7 +104,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def ProjectId(self):
-        """项目id，用户自定义，默认为0。
+        r"""项目id，用户自定义，默认为0。
         :rtype: int
         """
         return self._ProjectId
@@ -115,7 +115,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def ModelType(self):
-        """模型类型，1-默认模型。
+        r"""模型类型，1-默认模型。
         :rtype: int
         """
         return self._ModelType
@@ -126,7 +126,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def VoiceType(self):
-        """音色 ID，包括标准音色与精品音色，精品音色拟真度更高，价格不同于标准音色，请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
+        r"""音色 ID，价格请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
         :rtype: int
         """
         return self._VoiceType
@@ -137,7 +137,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def PrimaryLanguage(self):
-        """主语言类型：<li>1-中文（默认）</li><li>2-英文</li><li>3-日文</li>
+        r"""主语言类型：<li>1-中文（默认）</li><li>2-英文</li><li>3-日文</li>
         :rtype: int
         """
         return self._PrimaryLanguage
@@ -148,7 +148,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def SampleRate(self):
-        """音频采样率：<li>16000：16k（默认）</li><li>8000：8k</li>
+        r"""音频采样率：<li>16000：16k（默认）</li><li>8000：8k</li>
         :rtype: int
         """
         return self._SampleRate
@@ -159,7 +159,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def Codec(self):
-        """返回音频格式，可取值：mp3（默认），wav，pcm
+        r"""返回音频格式，可取值：mp3（默认），wav，pcm
         :rtype: str
         """
         return self._Codec
@@ -170,7 +170,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def CallbackUrl(self):
-        """回调 URL，用户自行搭建的用于接收识别结果的服务URL。如果用户使用轮询方式获取识别结果，则无需提交该参数。[回调说明](https://cloud.tencent.com/document/product/1073/55746)
+        r"""回调 URL，用户自行搭建的用于接收识别结果的服务URL。如果用户使用轮询方式获取识别结果，则无需提交该参数。[回调说明](https://cloud.tencent.com/document/product/1073/55746)
         :rtype: str
         """
         return self._CallbackUrl
@@ -181,7 +181,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def EnableSubtitle(self):
-        """是否开启时间戳功能，默认为false。
+        r"""是否开启时间戳功能，默认为false。
         :rtype: bool
         """
         return self._EnableSubtitle
@@ -192,7 +192,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def VoiceoverDialogueSplit(self):
-        """旁白与对白文本解析，分别合成相应风格（仅适用于旁对白音色10510000、100510000），默认 false
+        r"""旁白与对白文本解析，分别合成相应风格（仅适用于旁对白音色10510000、100510000），默认 false
         :rtype: bool
         """
         return self._VoiceoverDialogueSplit
@@ -203,7 +203,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def EmotionCategory(self):
-        """控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、sajiao(撒娇)、disgusted(厌恶)、amaze(震惊)、peaceful(平静)、exciting(兴奋)、aojiao(傲娇)、jieshuo(解说)
+        r"""控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、sajiao(撒娇)、disgusted(厌恶)、amaze(震惊)、peaceful(平静)、exciting(兴奋)、aojiao(傲娇)、jieshuo(解说)
         :rtype: str
         """
         return self._EmotionCategory
@@ -214,7 +214,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def EmotionIntensity(self):
-        """控制合成音频情感程度，取值范围为[50,200],默认为100；只有EmotionCategory不为空时生效。
+        r"""控制合成音频情感程度，取值范围为[50,200],默认为100；只有EmotionCategory不为空时生效。
         :rtype: int
         """
         return self._EmotionIntensity
@@ -250,7 +250,7 @@ class CreateTtsTaskRequest(AbstractModel):
 
 
 class CreateTtsTaskRespData(AbstractModel):
-    """异步合成请求的返回数据
+    r"""异步合成请求的返回数据
 
     """
 
@@ -263,7 +263,7 @@ class CreateTtsTaskRespData(AbstractModel):
 
     @property
     def TaskId(self):
-        """任务ID，可通过此ID在轮询接口获取合成状态与结果。注意：TaskId数据类型为string
+        r"""任务ID，可通过此ID在轮询接口获取合成状态与结果。注意：TaskId数据类型为string
         :rtype: str
         """
         return self._TaskId
@@ -286,7 +286,7 @@ class CreateTtsTaskRespData(AbstractModel):
 
 
 class CreateTtsTaskResponse(AbstractModel):
-    """CreateTtsTask返回参数结构体
+    r"""CreateTtsTask返回参数结构体
 
     """
 
@@ -302,7 +302,7 @@ class CreateTtsTaskResponse(AbstractModel):
 
     @property
     def Data(self):
-        """任务 id
+        r"""任务 id
         :rtype: :class:`tencentcloud.tts.v20190823.models.CreateTtsTaskRespData`
         """
         return self._Data
@@ -313,7 +313,7 @@ class CreateTtsTaskResponse(AbstractModel):
 
     @property
     def RequestId(self):
-        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        r"""唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :rtype: str
         """
         return self._RequestId
@@ -331,7 +331,7 @@ class CreateTtsTaskResponse(AbstractModel):
 
 
 class DescribeTtsTaskStatusRequest(AbstractModel):
-    """DescribeTtsTaskStatus请求参数结构体
+    r"""DescribeTtsTaskStatus请求参数结构体
 
     """
 
@@ -344,7 +344,7 @@ class DescribeTtsTaskStatusRequest(AbstractModel):
 
     @property
     def TaskId(self):
-        """任务id
+        r"""任务id
         :rtype: str
         """
         return self._TaskId
@@ -367,7 +367,7 @@ class DescribeTtsTaskStatusRequest(AbstractModel):
 
 
 class DescribeTtsTaskStatusRespData(AbstractModel):
-    """获取异步合成结果的返回参数
+    r"""获取异步合成结果的返回参数
 
     """
 
@@ -395,7 +395,7 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def TaskId(self):
-        """任务标识。
+        r"""任务标识。
         :rtype: str
         """
         return self._TaskId
@@ -406,7 +406,7 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def Status(self):
-        """任务状态码，0：任务等待，1：任务执行中，2：任务成功，3：任务失败。
+        r"""任务状态码，0：任务等待，1：任务执行中，2：任务成功，3：任务失败。
         :rtype: int
         """
         return self._Status
@@ -417,7 +417,7 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def StatusStr(self):
-        """任务状态，waiting：任务等待，doing：任务执行中，success：任务成功，failed：任务失败。
+        r"""任务状态，waiting：任务等待，doing：任务执行中，success：任务成功，failed：任务失败。
         :rtype: str
         """
         return self._StatusStr
@@ -428,7 +428,7 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def ResultUrl(self):
-        """合成音频COS地址（链接有效期1天）。
+        r"""合成音频COS地址（链接有效期1天）。
         :rtype: str
         """
         return self._ResultUrl
@@ -439,7 +439,7 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def Subtitles(self):
-        """时间戳信息，若未开启时间戳，则返回空数组。
+        r"""时间戳信息，若未开启时间戳，则返回空数组。
         :rtype: list of Subtitle
         """
         return self._Subtitles
@@ -450,7 +450,7 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def ErrorMsg(self):
-        """失败原因说明。
+        r"""失败原因说明。
         :rtype: str
         """
         return self._ErrorMsg
@@ -483,7 +483,7 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
 
 class DescribeTtsTaskStatusResponse(AbstractModel):
-    """DescribeTtsTaskStatus返回参数结构体
+    r"""DescribeTtsTaskStatus返回参数结构体
 
     """
 
@@ -499,7 +499,7 @@ class DescribeTtsTaskStatusResponse(AbstractModel):
 
     @property
     def Data(self):
-        """任务状态返回
+        r"""任务状态返回
         :rtype: :class:`tencentcloud.tts.v20190823.models.DescribeTtsTaskStatusRespData`
         """
         return self._Data
@@ -510,7 +510,7 @@ class DescribeTtsTaskStatusResponse(AbstractModel):
 
     @property
     def RequestId(self):
-        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        r"""唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :rtype: str
         """
         return self._RequestId
@@ -528,7 +528,7 @@ class DescribeTtsTaskStatusResponse(AbstractModel):
 
 
 class Subtitle(AbstractModel):
-    """时间戳信息。
+    r"""时间戳信息。
 
     """
 
@@ -557,7 +557,7 @@ class Subtitle(AbstractModel):
 
     @property
     def Text(self):
-        """⽂本信息。
+        r"""⽂本信息。
         :rtype: str
         """
         return self._Text
@@ -568,7 +568,7 @@ class Subtitle(AbstractModel):
 
     @property
     def BeginTime(self):
-        """⽂本对应tts语⾳开始时间戳，单位ms。
+        r"""⽂本对应tts语⾳开始时间戳，单位ms。
         :rtype: int
         """
         return self._BeginTime
@@ -579,7 +579,7 @@ class Subtitle(AbstractModel):
 
     @property
     def EndTime(self):
-        """⽂本对应tts语⾳结束时间戳，单位ms。
+        r"""⽂本对应tts语⾳结束时间戳，单位ms。
         :rtype: int
         """
         return self._EndTime
@@ -590,7 +590,7 @@ class Subtitle(AbstractModel):
 
     @property
     def BeginIndex(self):
-        """该文本在时间戳数组中的开始位置，从0开始。
+        r"""该文本在时间戳数组中的开始位置，从0开始。
         :rtype: int
         """
         return self._BeginIndex
@@ -601,7 +601,7 @@ class Subtitle(AbstractModel):
 
     @property
     def EndIndex(self):
-        """该文本在时间戳数组中的结束位置，从0开始。
+        r"""该文本在时间戳数组中的结束位置，从0开始。
         :rtype: int
         """
         return self._EndIndex
@@ -612,7 +612,7 @@ class Subtitle(AbstractModel):
 
     @property
     def Phoneme(self):
-        """该字的音素。
+        r"""该字的音素。
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: str
         """
@@ -641,7 +641,7 @@ class Subtitle(AbstractModel):
 
 
 class TextToVoiceRequest(AbstractModel):
-    """TextToVoice请求参数结构体
+    r"""TextToVoice请求参数结构体
 
     """
 
@@ -660,10 +660,9 @@ class TextToVoiceRequest(AbstractModel):
         :type ProjectId: int
         :param _ModelType: 模型类型，1-默认模型。
         :type ModelType: int
-        :param _VoiceType: 音色 ID，包括标准音色、精品音色、大模型音色与基础版复刻音色。不同音色价格有差异，详情请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
-
+        :param _VoiceType: 音色 ID，包括精品音色、大模型音色与基础版复刻音色。不同音色价格有差异，详情请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。<br>若使用一句话版声音复刻，请填入固定值“200000000”。
         :type VoiceType: int
-        :param _FastVoiceType: 一句话版声音复刻音色ID，使用一句话版声音复刻音色时需填写。【已废弃】
+        :param _FastVoiceType: 一句话版声音复刻音色ID，使用一句话版声音复刻音色时需填写。
         :type FastVoiceType: str
         :param _PrimaryLanguage: 主语言类型：<li>1-中文（默认）</li><li>2-英文</li><li>3-日文</li>
         :type PrimaryLanguage: int
@@ -702,7 +701,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def Text(self):
-        """合成语音的源文本，按UTF-8编码统一计算。
+        r"""合成语音的源文本，按UTF-8编码统一计算。
 中文最大支持150个汉字（全角标点符号算一个汉字）；英文最大支持500个字母（半角标点符号算一个字母）。
         :rtype: str
         """
@@ -714,7 +713,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def SessionId(self):
-        """一次请求对应一个SessionId，会原样返回，建议传入类似于uuid的字符串防止重复。
+        r"""一次请求对应一个SessionId，会原样返回，建议传入类似于uuid的字符串防止重复。
         :rtype: str
         """
         return self._SessionId
@@ -725,7 +724,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def Volume(self):
-        """音量大小，范围[-10，10]，对应音量大小。默认为0，代表正常音量，值越大音量越高。
+        r"""音量大小，范围[-10，10]，对应音量大小。默认为0，代表正常音量，值越大音量越高。
         :rtype: float
         """
         return self._Volume
@@ -736,7 +735,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def Speed(self):
-        """语速，范围：[-2，6]，分别对应不同语速：<li>-2代表0.6倍</li><li>-1代表0.8倍</li><li>0代表1.0倍（默认）</li><li>1代表1.2倍</li><li>2代表1.5倍</li><li>6代表2.5倍</li>如果需要更细化的语速，可以保留小数点后 2 位，例如0.5/1.25/2.81等。<br>参数值与实际语速转换，可参考[代码示例](https://sdk-1300466766.cos.ap-shanghai.myqcloud.com/sample/speed_sample.tar.gz)
+        r"""语速，范围：[-2，6]，分别对应不同语速：<li>-2代表0.6倍</li><li>-1代表0.8倍</li><li>0代表1.0倍（默认）</li><li>1代表1.2倍</li><li>2代表1.5倍</li><li>6代表2.5倍</li>如果需要更细化的语速，可以保留小数点后 2 位，例如0.5/1.25/2.81等。<br>参数值与实际语速转换，可参考[代码示例](https://sdk-1300466766.cos.ap-shanghai.myqcloud.com/sample/speed_sample.tar.gz)
         :rtype: float
         """
         return self._Speed
@@ -747,7 +746,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def ProjectId(self):
-        """项目id，用户自定义，默认为0。
+        r"""项目id，用户自定义，默认为0。
         :rtype: int
         """
         return self._ProjectId
@@ -758,7 +757,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def ModelType(self):
-        """模型类型，1-默认模型。
+        r"""模型类型，1-默认模型。
         :rtype: int
         """
         return self._ModelType
@@ -769,8 +768,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def VoiceType(self):
-        """音色 ID，包括标准音色、精品音色、大模型音色与基础版复刻音色。不同音色价格有差异，详情请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
-
+        r"""音色 ID，包括精品音色、大模型音色与基础版复刻音色。不同音色价格有差异，详情请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。<br>若使用一句话版声音复刻，请填入固定值“200000000”。
         :rtype: int
         """
         return self._VoiceType
@@ -781,7 +779,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def FastVoiceType(self):
-        """一句话版声音复刻音色ID，使用一句话版声音复刻音色时需填写。【已废弃】
+        r"""一句话版声音复刻音色ID，使用一句话版声音复刻音色时需填写。
         :rtype: str
         """
         return self._FastVoiceType
@@ -792,7 +790,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def PrimaryLanguage(self):
-        """主语言类型：<li>1-中文（默认）</li><li>2-英文</li><li>3-日文</li>
+        r"""主语言类型：<li>1-中文（默认）</li><li>2-英文</li><li>3-日文</li>
         :rtype: int
         """
         return self._PrimaryLanguage
@@ -803,7 +801,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def SampleRate(self):
-        """音频采样率：
+        r"""音频采样率：
 <li>24000：24k（部分音色支持，请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)）</li>
 <li>16000：16k（默认）</li>
 <li>8000：8k</li>
@@ -817,7 +815,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def Codec(self):
-        """返回音频格式，可取值：wav（默认），mp3，pcm
+        r"""返回音频格式，可取值：wav（默认），mp3，pcm
         :rtype: str
         """
         return self._Codec
@@ -828,7 +826,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def EnableSubtitle(self):
-        """是否开启时间戳功能，默认为false。
+        r"""是否开启时间戳功能，默认为false。
         :rtype: bool
         """
         return self._EnableSubtitle
@@ -839,7 +837,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def SegmentRate(self):
-        """断句敏感阈值，默认值为：0，取值范围：[0,1,2]。该值越大越不容易断句，模型会更倾向于仅按照标点符号断句。此参数建议不要随意调整，可能会影响合成效果。
+        r"""断句敏感阈值，默认值为：0，取值范围：[0,1,2]。该值越大越不容易断句，模型会更倾向于仅按照标点符号断句。此参数建议不要随意调整，可能会影响合成效果。
         :rtype: int
         """
         return self._SegmentRate
@@ -850,7 +848,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def EmotionCategory(self):
-        """控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、sajiao(撒娇)、disgusted(厌恶)、amaze(震惊)、peaceful(平静)、exciting(兴奋)、aojiao(傲娇)、jieshuo(解说)
+        r"""控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、sajiao(撒娇)、disgusted(厌恶)、amaze(震惊)、peaceful(平静)、exciting(兴奋)、aojiao(傲娇)、jieshuo(解说)
 示例值：neutral
         :rtype: str
         """
@@ -862,7 +860,7 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def EmotionIntensity(self):
-        """控制合成音频情感程度，取值范围为[50,200],默认为100；只有EmotionCategory不为空时生效；
+        r"""控制合成音频情感程度，取值范围为[50,200],默认为100；只有EmotionCategory不为空时生效；
         :rtype: int
         """
         return self._EmotionIntensity
@@ -899,7 +897,7 @@ class TextToVoiceRequest(AbstractModel):
 
 
 class TextToVoiceResponse(AbstractModel):
-    """TextToVoice返回参数结构体
+    r"""TextToVoice返回参数结构体
 
     """
 
@@ -921,7 +919,7 @@ class TextToVoiceResponse(AbstractModel):
 
     @property
     def Audio(self):
-        """base64编码的wav/mp3音频数据
+        r"""base64编码的wav/mp3音频数据
         :rtype: str
         """
         return self._Audio
@@ -932,7 +930,7 @@ class TextToVoiceResponse(AbstractModel):
 
     @property
     def SessionId(self):
-        """一次请求对应一个SessionId
+        r"""一次请求对应一个SessionId
         :rtype: str
         """
         return self._SessionId
@@ -943,7 +941,7 @@ class TextToVoiceResponse(AbstractModel):
 
     @property
     def Subtitles(self):
-        """时间戳信息，若未开启时间戳，则返回空数组。
+        r"""时间戳信息，若未开启时间戳，则返回空数组。
         :rtype: list of Subtitle
         """
         return self._Subtitles
@@ -954,7 +952,7 @@ class TextToVoiceResponse(AbstractModel):
 
     @property
     def RequestId(self):
-        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        r"""唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :rtype: str
         """
         return self._RequestId
